# This file is automatically generated. Please do not modify.

from . import AsciiArt

mac = AsciiArt(match=r'''"mac"* | "Darwin"''', color='2 3 1 1 5 4', ascii=r"""
${c1}                    c.'
                 ,xNMM.
               .OMMMMo
               lMM"
     .;loddo:.  .olloddol;.
   cKMMMMMMMMMMNWMMMMMMMMMM0:
${c2} .KMMMMMMMMMMMMMMMMMMMMMMMWd.
 XMMMMMMMMMMMMMMMMMMMMMMMX.
${c3};MMMMMMMMMMMMMMMMMMMMMMMM:
:MMMMMMMMMMMMMMMMMMMMMMMM:
${c4}.MMMMMMMMMMMMMMMMMMMMMMMMX.
 kMMMMMMMMMMMMMMMMMMMMMMMMWd.
 ${c5}'XMMMMMMMMMMMMMMMMMMMMMMMMMMk
  'XMMMMMMMMMMMMMMMMMMMMMMMMK.
    ${c6}kMMMMMMMMMMMMMMMMMMMMMMd
     ;KMMMMMMMWXXWMMMMMMMk.
       "cooc*"    "*coo'"
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

lede = AsciiArt(match=r'''"LEDE"*''', color='4 7 1', ascii=r"""
${c1}     _________
    /        /\
   /  LE    /  \
  /    DE  /    \
 /________/  LE  \
 \        \   DE /
  \    LE  \    /
   \  DE    \  /
    \________\/
""")
    


#!/usr/bin/env python3
import shlex
from subprocess import check_output

import pyperclip


def copy_comment():
    # Get commit SHA
    sha = check_output(shlex.split('git rev-parse --short HEAD')).decode().strip()

    # Copy comment to clipboard
    comment = f"""
Thank you for reporting the issue!

This issue is [fixed in hyfetch by commit {sha}](https://github.com/hykilpikonna/hyfetch/commit/{sha}). This repo (dylanaraps/neofetch) seems to be no longer maintained.

[HyFetch](https://github.com/hykilpikonna/hyfetch) is a fork of neofetch with LGBTQ pride flags, but the repo also maintains an updated version of the original neofetch, addressing many issues and pull requests.

Read the ["Running Updated Original Neofetch" section](https://github.com/hykilpikonna/hyfetch#running-updated-original-neofetch) for more info!
    """
    pyperclip.copy(comment.strip())
    print()
    print('Comment response copied to clipboard.')


if __name__ == '__main__':
    copy_comment()



from __future__ import annotations

import os
import platform
import sys

from .color_util import RGB, AnsiMode


class OSCException(Exception):
    pass


def unix_detect_ansi_mode() -> AnsiMode | None:
    """
    Translated from Termenv's ColorProfile():
    https://github.com/muesli/termenv/blob/42ca574de3e99a262e1724d2fb8daa1aea68a5b9/termenv_unix.go#L23

    :return: Ansi mode
    """
    if not sys.stdout.isatty():
        return 'ansi'

    term = os.environ.get('TERM')
    color_term = os.environ.get('COLORTERM')

    if color_term == 'truecolor' or color_term == '24bit':
        if term.startswith('screen') and os.environ.get('TERM_PROGRAM') != 'tmux':
            return '8bit'
        return 'rgb'

    elif color_term == 'true' or color_term == 'yes':
        return '8bit'

    if term == 'xterm-kitty':
        return 'rgb'
    elif term == 'linux':
        return 'ansi'

    if '256color' in term:
        return 'rgb'
    if 'color' in term:
        return '8bit'
    if 'ansi' in term:
        return 'ansi'

    return None


def windows_detect_ansi_mode() -> AnsiMode | None:
    """
    Translated from Termenv's ColorProfile():
    https://github.com/muesli/termenv/blob/42ca574de3e99a262e1724d2fb8daa1aea68a5b9/termenv_windows.go#L13

    :return: Ansi mode
    """
    if not sys.stdout.isatty():
        return 'ansi'

    if os.environ.get("ConEmuANSI") == "ON":
        return 'rgb'

    release, _, build = map(int, platform.version().split('.'))
    if build < 10586 or release < 10:
        # No ANSI support before Windows 10 build 10586.
        if os.environ.get('ANSICON'):
            conv = os.environ.get('ANSICON_VER')
            if int(conv) < 181:
                return 'ansi'
            return '8bit'
        return 'ansi'

    if build < 14931:
        # No true color support before build 14931.
        return '8bit'

    return 'rgb'


def detect_ansi_mode() -> AnsiMode | None:
    system = platform.system().lower()
    if system.startswith("linux") or system.startswith("darwin"):
        return unix_detect_ansi_mode()
    if system.startswith("windows"):
        return windows_detect_ansi_mode()
    return None


def unix_read_osc(seq: int) -> str:
    import termios
    import tty
    import signal
    from select import select

    # screen/tmux can't support OSC, because they can be connected to multiple
    # terminals concurrently.
    term = os.environ.get('TERM')
    if term.startswith("screen") or term.startswith("tmux"):
        raise OSCException("Screen/tmux not supported")

    t = sys.stdout
    if not t.isatty():
        raise OSCException("Not a tty")

    fd = sys.stdin.fileno()

    # Set raw mode
    settings = termios.tcgetattr(fd)
    tty.setraw(sys.stdin.fileno())

    # first, send OSC query, which is ignored by terminal which do not support it
    t.write(f"\x1b]{seq};?\x1b\\")
    t.flush()

    # stdin response timeout should be higher for ssh sessions
    timeout = 0.05 if (os.environ.get('SSH_TTY') or os.environ.get('SSH_SESSION')) is None else 0.5

    # Wait for input to appear
    if not select([sys.stdin], [], [], timeout)[0]:
        # Reset terminal back to normal mode (previously set to raw mode)
        termios.tcsetattr(fd, termios.TCSADRAIN, settings)
        raise OSCException("No response received")

    # Read until termination, or if it doesn't terminate, read until 1 second passes
    def handler(signum, frame):
        raise IOError()
    signal.signal(signal.SIGALRM, handler)
    signal.setitimer(signal.ITIMER_REAL, timeout, 1)
    code = ""
    try:
        for _ in range(28):
            code += sys.stdin.read(1)

            # Terminate with sequence terminator [\ or bell ^G
            if code.endswith('\x1b\\') or code.endswith('\a'):
                break
        signal.alarm(0)
    except IOError:
        pass

    # Reset terminal back to normal mode (previously set to raw mode)
    termios.tcsetattr(fd, termios.TCSADRAIN, settings)

    # Validate output
    if not code:
        raise OSCException("No response received")

    start = f"\x1b]{seq};"
    if not code.startswith(start):
        raise OSCException("Received response is not an OSC response")

    # Strip starting code and termination code
    code = code.lstrip(start).rstrip("\x1b\\").rstrip('\a')

    return code


def get_background_color() -> RGB | None:
    system = platform.system().lower()
    if system.startswith("linux") or system.startswith("darwin"):
        try:
            osc = unix_read_osc(11).lstrip("rgb:")
            return RGB.from_hex(''.join([v[:2] for v in osc.split('/')]))
        except Exception:
            return None
    if system.startswith("windows"):
        return None





# This file is automatically generated. Please do not modify.

from . import AsciiArt

kslinux = AsciiArt(match=r'''"KSLinux"*''', color='4 7 1', ascii=r"""
${c1} K   K U   U RRRR   ooo
 K  K  U   U R   R o   o
 KKK   U   U RRRR  o   o
 K  K  U   U R  R  o   o
 K   K  UUU  R   R  ooo

${c2}  SSS   AAA  W   W  AAA
 S     A   A W   W A   A
  SSS  AAAAA W W W AAAAA
     S A   A WW WW A   A
  SSS  A   A W   W A   A
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

t2 = AsciiArt(match=r'''"t2"*''', color='7 4', ascii=r"""
${c2}
TTTTTTTTTT
    tt   ${c1}222${c2}
    tt  ${c1}2   2${c2}
    tt     ${c1}2${c2}
    tt    ${c1}2${c2}
    tt  ${c1}22222${c2}
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

rocky = AsciiArt(match=r'''"rocky"*''', color='35', ascii=r"""
${c1}          __wgliliiligw_,
       _williiiiiiliilililw,
     _%iiiiiilililiiiiiiiiiii_
   .Qliiiililiiiiiiililililiilm.
  _iiiiiliiiiiililiiiiiiiiiiliil,
 .lililiiilililiiiilililililiiiii,
_liiiiiiliiiiiiiliiiiiF{iiiiiilili,
jliililiiilililiiili@`  ~ililiiiiiL
iiiliiiiliiiiiiili>`      ~liililii
liliiiliiilililii`         -9liiiil
iiiiiliiliiiiii~             "4lili
4ililiiiiilil~|      -w,       )4lf
-liiiiililiF'       _liig,       )'
 )iiiliii@`       _QIililig,
  )iiii>`       .Qliliiiililw
   )<>~       .mliiiiiliiiiiil,
            _gllilililiililii~
           giliiiiiiiiiiiiT`
          -^~$ililili@~~'
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

astos = AsciiArt(match=r'''"astOS"*''', color='8', ascii=r"""
${c1}                oQA#$%UMn
                H       9
                G       #
                6       %
                ?#M#%KW3"
                  // \\
                //     \\
              //         \\
            //             \\
        n%@$DK&ML       .0O3#@&M_
        P       #       8       W
        H       U       G       #
        B       N       O       @
        C&&#%HNAR       'WS3QMHB"
          // \\              \\
        //     \\              \\
      //         \\              \\
    //             \\              \\
uURF$##Bv       nKWB$%ABc       aM@3R@D@b
8       M       @       O       #       %
%       &       G       U       @       @
&       @       #       %       %       #
!HGN@MNCf       t&$9#%HQr       ?@G#6S@QP
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

semc = AsciiArt(match=r'''"semc"*''', color='2 8 1', ascii=r"""
${c1}            /\
     ______/  \
    /      |()| ${c2}E M C
${c1}   |   (-- |  |
    \   \  |  |
.----)   | |__|
|_______/ / ${c3}"${c1}  \
              ${c3}"
            "
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

linux_mint_old = AsciiArt(match=r'''"Linux Mint Old"* | "LinuxMintOld"* | "mint_old"*''', color='2 7', ascii=r"""
${c1}MMMMMMMMMMMMMMMMMMMMMMMMMmds+.
MMm----::-://////////////oymNMd+`
MMd      ${c2}/++                ${c1}-sNMd:
MMNso/`  ${c2}dMM    `.::-. .-::.` ${c1}.hMN:
ddddMMh  ${c2}dMM   :hNMNMNhNMNMNh: ${c1}`NMm
    NMm  ${c2}dMM  .NMN/-+MMM+-/NMN` ${c1}dMM
    NMm  ${c2}dMM  -MMm  `MMM   dMM. ${c1}dMM
    NMm  ${c2}dMM  -MMm  `MMM   dMM. ${c1}dMM
    NMm  ${c2}dMM  .mmd  `mmm   yMM. ${c1}dMM
    NMm  ${c2}dMM`  ..`   ...   ydm. ${c1}dMM
    hMM- ${c2}+MMd/-------...-:sdds  ${c1}dMM
    -NMm- ${c2}:hNMNNNmdddddddddy/`  ${c1}dMM
     -dMNs-${c2}``-::::-------.``    ${c1}dMM
      `/dMNmy+/:-------------:/yMMM
         ./ydNMMMMMMMMMMMMMMMMMMMMM
            .MMMMMMMMMMMMMMMMMMM
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

univention = AsciiArt(match=r'''"Univention"*''', color='1 7', ascii=r"""
${c1}         ./osssssssssssssssssssssso+-
       `ohhhhhhhhhhhhhhhhhhhhhhhhhhhhy:
       shhhhhhhhhhhhhhhhhhhhhhhhhhhhhhh-
   `-//${c2}sssss${c1}/hhhhhhhhhhhhhh+${c2}s${c1}.hhhhhhhhh+
 .ohhhy${c2}sssss${c1}.hhhhhhhhhhhhhh.${c2}sss${c1}+hhhhhhh+
.yhhhhy${c2}sssss${c1}.hhhhhhhhhhhhhh.${c2}ssss${c1}:hhhhhh+
+hhhhhy${c2}sssss${c1}.hhhhhhhhhhhhhh.${c2}sssss${c1}yhhhhh+
+hhhhhy${c2}sssss${c1}.hhhhhhhhhhhhhh.${c2}sssss${c1}yhhhhh+
+hhhhhy${c2}sssss${c1}.hhhhhhhhhhhhhh.${c2}sssss${c1}yhhhhh+
+hhhhhy${c2}sssss${c1}.hhhhhhhhhhhhhh.${c2}sssss${c1}yhhhhh+
+hhhhhy${c2}sssss${c1}.hhhhhhhhhhhhhh.${c2}sssss${c1}yhhhhh+
+hhhhhy${c2}sssss${c1}.hhhhhhhhhhhhhh.${c2}sssss${c1}yhhhhh+
+hhhhhy${c2}sssss${c1}.hhhhhhhhhhhhhh.${c2}sssss${c1}yhhhhh+
+hhhhhy${c2}ssssss${c1}+yhhhhhhhhhhy/${c2}ssssss${c1}yhhhhh+
+hhhhhh:${c2}sssssss${c1}:hhhhhhh+${c2}.ssssssss${c1}yhhhhy.
+hhhhhhh+`${c2}ssssssssssssssss${c1}hh${c2}sssss${c1}yhhho`
+hhhhhhhhhs+${c2}ssssssssssss${c1}+hh+${c2}sssss${c1}/:-`
-hhhhhhhhhhhhhhhhhhhhhhhhhhhhhhho
 :yhhhhhhhhhhhhhhhhhhhhhhhhhhhh+`
   -+ossssssssssssssssssssss+:`
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

iglunix = AsciiArt(match=r'''"iglunix"*|"iglu"*''', color='8', ascii=r"""
${c1}     |
     |        |
              |
|    ________
|  /\   |    \
  /  \  |     \  |
 /    \        \ |
/      \________\
\      /        /
 \    /        /
  \  /        /
   \/________/
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

clear_linux_os = AsciiArt(match=r'''"Clear Linux OS"* | "Clear_Linux"*''', color='4 3 7 6', ascii=r"""
${c1}          BBB
       BBBBBBBBB
     BBBBBBBBBBBBBBB
   BBBBBBBBBBBBBBBBBBBB
   BBBBBBBBBBB         BBB
  BBBBBBBB${c2}YYYYY
${c1}  BBBBBBBB${c2}YYYYYY
${c1}  BBBBBBBB${c2}YYYYYYY
${c1}  BBBBBBBBB${c2}YYYYY${c3}W
${c4} GG${c1}BBBBBBBY${c2}YYYY${c3}WWW
${c4} GGG${c1}BBBBBBB${c2}YY${c3}WWWWWWWW
${c4} GGGGGG${c1}BBBBBB${c3}WWWWWWWW
${c4} GGGGGGGG${c1}BBBB${c3}WWWWWWWW
${c4}GGGGGGGGGGG${c1}BBB${c3}WWWWWWW
${c4}GGGGGGGGGGGGG${c1}B${c3}WWWWWW
${c4}GGGGGGGG${c3}WWWWWWWWWWW
${c4}GG${c3}WWWWWWWWWWWWWWWW
 WWWWWWWWWWWWWWWW
      WWWWWWWWWW
          WWW
""")
    


# This file is automatically generated. Please do not modify.

from __future__ import annotations

from . import AsciiArt

def detect(name: str) -> AsciiArt | None:
    if not name:
        return None
    name = name.lower()
    if name.startswith('adélie') or name.startswith('adelie'):
        from .adélie import adélie
        return adélie
    
    if name.startswith('aix'):
        from .aix import aix
        return aix
    
    if name.startswith('aperio gnu/linux'):
        from .aperio_gnu_linux import aperio_gnu_linux
        return aperio_gnu_linux
    
    if name.startswith('aperture'):
        from .aperture import aperture
        return aperture
    
    if name.startswith('asahi'):
        from .asahi import asahi
        return asahi
    
    if name.startswith('hash'):
        from .hash import hash
        return hash
    
    if name.startswith('hardclanz'):
        from .hardclanz import hardclanz
        return hardclanz
    
    if name.startswith('almalinux'):
        from .almalinux import almalinux
        return almalinux
    
    if name.startswith('exodia predator os') or name.startswith('exodia-predator') or name.startswith('predator'):
        from .exodia_predator_os import exodia_predator_os
        return exodia_predator_os
    
    if name == 'alpine_small':
        from .alpine_small import alpine_small
        return alpine_small
    
    if name.startswith('alpine'):
        from .alpine import alpine
        return alpine
    
    if name.startswith('alter'):
        from .alter import alter
        return alter
    
    if name.startswith('amazon'):
        from .amazon import amazon
        return amazon
    
    if name.startswith('amogos'):
        from .amogos import amogos
        return amogos
    
    if name.startswith('anarchy'):
        from .anarchy import anarchy
        return anarchy
    
    if name.startswith('android_small'):
        from .android_small import android_small
        return android_small
    
    if name.startswith('android'):
        from .android import android
        return android
    
    if name.startswith('arselinux'):
        from .arselinux import arselinux
        return arselinux
    
    if name.startswith('instantos'):
        from .instantos import instantos
        return instantos
    
    if name.startswith('antergos'):
        from .antergos import antergos
        return antergos
    
    if name.startswith('antix'):
        from .antix import antix
        return antix
    
    if name.startswith('afterglow'):
        from .afterglow import afterglow
        return afterglow
    
    if name.startswith('aosc os'):
        from .aosc_os import aosc_os
        return aosc_os
    
    if name.startswith('apricity'):
        from .apricity import apricity
        return apricity
    
    if name.startswith('archcraft_ascii'):
        from .archcraft_ascii import archcraft_ascii
        return archcraft_ascii
    
    if name.startswith('archcraft_minimal'):
        from .archcraft_minimal import archcraft_minimal
        return archcraft_minimal
    
    if name.startswith('archcraft'):
        from .archcraft import archcraft
        return archcraft
    
    if name.startswith('arcolinux_small'):
        from .arcolinux_small import arcolinux_small
        return arcolinux_small
    
    if name.startswith('arcolinux'):
        from .arcolinux import arcolinux
        return arcolinux
    
    if name == 'arch_small':
        from .arch_small import arch_small
        return arch_small
    
    if name == 'arch_old':
        from .arch_old import arch_old
        return arch_old
    
    if name.startswith('archbox'):
        from .archbox import archbox
        return archbox
    
    if name.startswith('archlabs'):
        from .archlabs import archlabs
        return archlabs
    
    if name.startswith('archstrike'):
        from .archstrike import archstrike
        return archstrike
    
    if name.startswith('astos'):
        from .astos import astos
        return astos
    
    if (name.startswith('xferience') or name.endswith('xferience')):
        from .xferience import xferience
        return xferience
    
    if name.startswith('stock linux'):
        from .stock_linux import stock_linux
        return stock_linux
    
    if name.startswith('archmerge'):
        from .archmerge import archmerge
        return archmerge
    
    if name.startswith('aeros'):
        from .aeros import aeros
        return aeros
    
    if name.startswith('arch'):
        from .arch import arch
        return arch
    
    if name.startswith('unicodearch'):
        from .unicodearch import unicodearch
        return unicodearch
    
    if name.startswith('artix_small'):
        from .artix_small import artix_small
        return artix_small
    
    if name.startswith('artix'):
        from .artix import artix
        return artix
    
    if name.startswith('cobalt'):
        from .cobalt import cobalt
        return cobalt
    
    if name.startswith('arya'):
        from .arya import arya
        return arya
    
    if name.startswith('asteroidos'):
        from .asteroidos import asteroidos
        return asteroidos
    
    if name.startswith('athena'):
        from .athena import athena
        return athena
    
    if name.startswith('azos'):
        from .azos import azos
        return azos
    
    if name.startswith('bedrock'):
        from .bedrock import bedrock
        return bedrock
    
    if name.startswith('biglinux'):
        from .biglinux import biglinux
        return biglinux
    
    if name.startswith('bitrig'):
        from .bitrig import bitrig
        return bitrig
    
    if name.startswith('blackarch'):
        from .blackarch import blackarch
        return blackarch
    
    if name.startswith('blackpanther') or name.startswith('blackpanther'):
        from .blackpanther import blackpanther
        return blackpanther
    
    if name.startswith('matuusos'):
        from .matuusos import matuusos
        return matuusos
    
    if name.startswith('blag'):
        from .blag import blag
        return blag
    
    if name.startswith('blankon'):
        from .blankon import blankon
        return blankon
    
    if name.startswith('bluelight'):
        from .bluelight import bluelight
        return bluelight
    
    if name.startswith('bodhi'):
        from .bodhi import bodhi
        return bodhi
    
    if name.startswith('bonsai'):
        from .bonsai import bonsai
        return bonsai
    
    if name == 'bsd':
        from .bsd import bsd
        return bsd
    
    if name.startswith('bunsenlabs'):
        from .bunsenlabs import bunsenlabs
        return bunsenlabs
    
    if name.startswith('cachyos'):
        from .cachyos import cachyos
        return cachyos
    
    if name.startswith('calculate'):
        from .calculate import calculate
        return calculate
    
    if name.startswith('carbs'):
        from .carbs import carbs
        return carbs
    
    if name == 'calinixos':
        from .calinixos import calinixos
        return calinixos
    
    if name.startswith('calinixos_small'):
        from .calinixos_small import calinixos_small
        return calinixos_small
    
    if name.startswith('cbl-mariner'):
        from .cbl_mariner import cbl_mariner
        return cbl_mariner
    
    if name.startswith('celos'):
        from .celos import celos
        return celos
    
    if name.startswith('centos_small'):
        from .centos_small import centos_small
        return centos_small
    
    if name.startswith('centos'):
        from .centos import centos
        return centos
    
    if name.startswith('center'):
        from .center import center
        return center
    
    if name.startswith('chakra'):
        from .chakra import chakra
        return chakra
    
    if name.startswith('chaletos'):
        from .chaletos import chaletos
        return chaletos
    
    if name.startswith('chapeau'):
        from .chapeau import chapeau
        return chapeau
    
    if name.startswith('chonkysealos'):
        from .chonkysealos import chonkysealos
        return chonkysealos
    
    if name.startswith('chrom'):
        from .chrom import chrom
        return chrom
    
    if name.startswith('cleanjaro_small'):
        from .cleanjaro_small import cleanjaro_small
        return cleanjaro_small
    
    if name.startswith('cleanjaro'):
        from .cleanjaro import cleanjaro
        return cleanjaro
    
    if name.startswith('clearos'):
        from .clearos import clearos
        return clearos
    
    if name.startswith('clear linux os') or name.startswith('clear_linux'):
        from .clear_linux_os import clear_linux_os
        return clear_linux_os
    
    if name.startswith('clover'):
        from .clover import clover
        return clover
    
    if name.startswith('condres'):
        from .condres import condres
        return condres
    
    if name.startswith('container linux by coreos') or name.startswith('container_linux'):
        from .container_linux_by_coreos import container_linux_by_coreos
        return container_linux_by_coreos
    
    if name == 'crux_small' or name.startswith('kiss'):
        from .crux_small import crux_small
        return crux_small
    
    if name.startswith('crux'):
        from .crux import crux
        return crux
    
    if (name.startswith('crystal linux') or name.endswith('crystal linux')):
        from .crystal_linux import crystal_linux
        return crystal_linux
    
    if (name.startswith('cucumber') or name.endswith('cucumber')):
        from .cucumber import cucumber
        return cucumber
    
    if name.startswith('cutefishos'):
        from .cutefishos import cutefishos
        return cutefishos
    
    if name.startswith('cuteos'):
        from .cuteos import cuteos
        return cuteos
    
    if name.startswith('cyberos'):
        from .cyberos import cyberos
        return cyberos
    
    if name.startswith('dahlia'):
        from .dahlia import dahlia
        return dahlia
    
    if name == 'debian_small':
        from .debian_small import debian_small
        return debian_small
    
    if name.startswith('debian'):
        from .debian import debian
        return debian
    
    if name.startswith('digital unix'):
        from .digital_unix import digital_unix
        return digital_unix
    
    if name.startswith('droidian'):
        from .droidian import droidian
        return droidian
    
    if name.startswith('deepin'):
        from .deepin import deepin
        return deepin
    
    if name.startswith('openkylin'):
        from .openkylin import openkylin
        return openkylin
    
    if name == 'desaos':
        from .desaos import desaos
        return desaos
    
    if name.startswith('devuan'):
        from .devuan import devuan
        return devuan
    
    if name.startswith('dietpi'):
        from .dietpi import dietpi
        return dietpi
    
    if name.startswith('dracos'):
        from .dracos import dracos
        return dracos
    
    if name == 'darkos':
        from .darkos import darkos
        return darkos
    
    if name.startswith('itc'):
        from .itc import itc
        return itc
    
    if name.startswith('dragonfly_old'):
        from .dragonfly_old import dragonfly_old
        return dragonfly_old
    
    if name.startswith('dragonfly_small'):
        from .dragonfly_small import dragonfly_small
        return dragonfly_small
    
    if name.startswith('dragonfly'):
        from .dragonfly import dragonfly
        return dragonfly
    
    if name.startswith('drauger'):
        from .drauger import drauger
        return drauger
    
    if name.startswith('elementary_small'):
        from .elementary_small import elementary_small
        return elementary_small
    
    if name.startswith('elementary'):
        from .elementary import elementary
        return elementary
    
    if name.startswith('elive'):
        from .elive import elive
        return elive
    
    if name.startswith('endeavouros_small'):
        from .endeavouros_small import endeavouros_small
        return endeavouros_small
    
    if name.startswith('endeavouros'):
        from .endeavouros import endeavouros
        return endeavouros
    
    if name.startswith('encryptos'):
        from .encryptos import encryptos
        return encryptos
    
    if name.startswith('endless'):
        from .endless import endless
        return endless
    
    if name.startswith('enso'):
        from .enso import enso
        return enso
    
    if name.startswith('eurolinux'):
        from .eurolinux import eurolinux
        return eurolinux
    
    if name.startswith('evolutionos'):
        from .evolutionos import evolutionos
        return evolutionos
    
    if name.startswith('exherbo'):
        from .exherbo import exherbo
        return exherbo
    
    if name == 'fedora_small':
        from .fedora_small import fedora_small
        return fedora_small
    
    if name.startswith('fedora_old') or name.startswith('rfremix'):
        from .fedora_old import fedora_old
        return fedora_old
    
    if name.startswith('fedora'):
        from .fedora import fedora
        return fedora
    
    if name.startswith('feren'):
        from .feren import feren
        return feren
    
    if name.startswith('femboyos'):
        from .femboyos import femboyos
        return femboyos
    
    if name.startswith('finnix'):
        from .finnix import finnix
        return finnix
    
    if name == 'freebsd_small':
        from .freebsd_small import freebsd_small
        return freebsd_small
    
    if name.startswith('freebsd') or name.startswith('hardenedbsd'):
        from .freebsd import freebsd
        return freebsd
    
    if name.startswith('freemint'):
        from .freemint import freemint
        return freemint
    
    if name.startswith('frugalware'):
        from .frugalware import frugalware
        return frugalware
    
    if name.startswith('funtoo'):
        from .funtoo import funtoo
        return funtoo
    
    if name.startswith('galliumos'):
        from .galliumos import galliumos
        return galliumos
    
    if name == 'garuda_small':
        from .garuda_small import garuda_small
        return garuda_small
    
    if name.startswith('garuda'):
        from .garuda import garuda
        return garuda
    
    if name == 'gentoo_small':
        from .gentoo_small import gentoo_small
        return gentoo_small
    
    if name.startswith('gentoo'):
        from .gentoo import gentoo
        return gentoo
    
    if name.startswith('pentoo'):
        from .pentoo import pentoo
        return pentoo
    
    if name.startswith('glaucus'):
        from .glaucus import glaucus
        return glaucus
    
    if name.startswith('gnewsense'):
        from .gnewsense import gnewsense
        return gnewsense
    
    if name.startswith('gnome'):
        from .gnome import gnome
        return gnome
    
    if name == 'gnu':
        from .gnu import gnu
        return gnu
    
    if name.startswith('gobolinux'):
        from .gobolinux import gobolinux
        return gobolinux
    
    if name.startswith('grapheneos'):
        from .grapheneos import grapheneos
        return grapheneos
    
    if name.startswith('grombyang'):
        from .grombyang import grombyang
        return grombyang
    
    if name.startswith('guix_small'):
        from .guix_small import guix_small
        return guix_small
    
    if name.startswith('guix'):
        from .guix import guix
        return guix
    
    if name.startswith('haiku_small'):
        from .haiku_small import haiku_small
        return haiku_small
    
    if name.startswith('haiku'):
        from .haiku import haiku
        return haiku
    
    if name.startswith('hamonikr'):
        from .hamonikr import hamonikr
        return hamonikr
    
    if name.startswith('huayra'):
        from .huayra import huayra
        return huayra
    
    if name.startswith('hydroos'):
        from .hydroos import hydroos
        return hydroos
    
    if name.startswith('hyperbola_small'):
        from .hyperbola_small import hyperbola_small
        return hyperbola_small
    
    if name.startswith('hyperbola'):
        from .hyperbola import hyperbola
        return hyperbola
    
    if name.startswith('hybrid'):
        from .hybrid import hybrid
        return hybrid
    
    if name.startswith('iglunix') or name.startswith('iglu'):
        from .iglunix import iglunix
        return iglunix
    
    if name.startswith('interix'):
        from .interix import interix
        return interix
    
    if name.startswith('januslinux') or name.startswith('janus') or name.startswith('ataraxia linux') or name.startswith('ataraxia'):
        from .januslinux import januslinux
        return januslinux
    
    if name.startswith('kaisen'):
        from .kaisen import kaisen
        return kaisen
    
    if name == 'kali_small' or name == 'kalilinux_small' or name == 'kali_linux_small':
        from .kali_small import kali_small
        return kali_small
    
    if name.startswith('kali'):
        from .kali import kali
        return kali
    
    if name.startswith('kaos'):
        from .kaos import kaos
        return kaos
    
    if name.startswith('kde'):
        from .kde import kde
        return kde
    
    if name.startswith('kibojoe'):
        from .kibojoe import kibojoe
        return kibojoe
    
    if name.startswith('kogaion'):
        from .kogaion import kogaion
        return kogaion
    
    if name.startswith('korora'):
        from .korora import korora
        return korora
    
    if name.startswith('kslinux'):
        from .kslinux import kslinux
        return kslinux
    
    if name.startswith('kubuntu'):
        from .kubuntu import kubuntu
        return kubuntu
    
    if name.startswith('lainos'):
        from .lainos import lainos
        return lainos
    
    if name.startswith('lede'):
        from .lede import lede
        return lede
    
    if name == 'langitketujuh_old':
        from .langitketujuh_old import langitketujuh_old
        return langitketujuh_old
    
    if name.startswith('langitketujuh'):
        from .langitketujuh import langitketujuh
        return langitketujuh
    
    if name.startswith('laxeros'):
        from .laxeros import laxeros
        return laxeros
    
    if name.startswith('libreelec'):
        from .libreelec import libreelec
        return libreelec
    
    if name == 'linux':
        from .linux import linux
        return linux
    
    if name == 'linux_small':
        from .linux_small import linux_small
        return linux_small
    
    if name.startswith('linuxlite_small'):
        from .linuxlite_small import linuxlite_small
        return linuxlite_small
    
    if name.startswith('linux lite') or name.startswith('linux_lite'):
        from .linux_lite import linux_lite
        return linux_lite
    
    if name.startswith('lmde'):
        from .lmde import lmde
        return lmde
    
    if name.startswith('lubuntu'):
        from .lubuntu import lubuntu
        return lubuntu
    
    if name.startswith('lunar'):
        from .lunar import lunar
        return lunar
    
    if name == 'mac"*"_small':
        from .mac_small import mac_small
        return mac_small
    
    if name.startswith('mac') or name == 'darwin':
        from .mac import mac
        return mac
    
    if name.startswith('mageia_small'):
        from .mageia_small import mageia_small
        return mageia_small
    
    if name.startswith('mageia'):
        from .mageia import mageia
        return mageia
    
    if name.startswith('magpieos'):
        from .magpieos import magpieos
        return magpieos
    
    if name.startswith('mainsailos_small'):
        from .mainsailos_small import mainsailos_small
        return mainsailos_small
    
    if name.startswith('mainsailos'):
        from .mainsailos import mainsailos
        return mainsailos
    
    if name.startswith('mandriva') or name.startswith('mandrake'):
        from .mandriva import mandriva
        return mandriva
    
    if name.startswith('manjaro_small'):
        from .manjaro_small import manjaro_small
        return manjaro_small
    
    if name.startswith('manjaro'):
        from .manjaro import manjaro
        return manjaro
    
    if name.startswith('massos'):
        from .massos import massos
        return massos
    
    if name.startswith('tearch'):
        from .tearch import tearch
        return tearch
    
    if name.startswith('maui'):
        from .maui import maui
        return maui
    
    if name.startswith('meowix'):
        from .meowix import meowix
        return meowix
    
    if name.startswith('mer'):
        from .mer import mer
        return mer
    
    if name.startswith('minix'):
        from .minix import minix
        return minix
    
    if name.startswith('miracle linux') or name.startswith('miracle_linux'):
        from .miracle_linux import miracle_linux
        return miracle_linux
    
    if name.startswith('linspire') or name.startswith('freespire') or name.startswith('lindows'):
        from .linspire import linspire
        return linspire
    
    if name.startswith('linuxmint_small'):
        from .linuxmint_small import linuxmint_small
        return linuxmint_small
    
    if name.startswith('linux mint old') or name.startswith('linuxmintold') or name.startswith('mint_old'):
        from .linux_mint_old import linux_mint_old
        return linux_mint_old
    
    if name.startswith('linux mint') or name.startswith('linuxmint') or name.startswith('mint'):
        from .linux_mint import linux_mint
        return linux_mint
    
    if name.startswith('live raizo') or name.startswith('live_raizo'):
        from .live_raizo import live_raizo
        return live_raizo
    
    if name.startswith('mx_small'):
        from .mx_small import mx_small
        return mx_small
    
    if name.startswith('mx'):
        from .mx import mx
        return mx
    
    if name.startswith('namib'):
        from .namib import namib
        return namib
    
    if name.startswith('nekos'):
        from .nekos import nekos
        return nekos
    
    if name.startswith('neptune'):
        from .neptune import neptune
        return neptune
    
    if name.startswith('netbsd_small'):
        from .netbsd_small import netbsd_small
        return netbsd_small
    
    if name.startswith('netbsd'):
        from .netbsd import netbsd
        return netbsd
    
    if name.startswith('netrunner'):
        from .netrunner import netrunner
        return netrunner
    
    if name.startswith('nitrux'):
        from .nitrux import nitrux
        return nitrux
    
    if name == 'nixos_small':
        from .nixos_small import nixos_small
        return nixos_small
    
    if name.startswith('nixos_old'):
        from .nixos_old import nixos_old
        return nixos_old
    
    if name.startswith('nixos'):
        from .nixos import nixos
        return nixos
    
    if name.startswith('nobara'):
        from .nobara import nobara
        return nobara
    
    if name.startswith('nomadbsd'):
        from .nomadbsd import nomadbsd
        return nomadbsd
    
    if name.startswith('ghostbsd'):
        from .ghostbsd import ghostbsd
        return ghostbsd
    
    if name.startswith('nurunner'):
        from .nurunner import nurunner
        return nurunner
    
    if name.startswith('nutyx'):
        from .nutyx import nutyx
        return nutyx
    
    if name.startswith('obrevenge'):
        from .obrevenge import obrevenge
        return obrevenge
    
    if name.startswith('omnios'):
        from .omnios import omnios
        return omnios
    
    if name == 'openbsd_small':
        from .openbsd_small import openbsd_small
        return openbsd_small
    
    if name.startswith('openbsd'):
        from .openbsd import openbsd
        return openbsd
    
    if name.startswith('openeuler'):
        from .openeuler import openeuler
        return openeuler
    
    if name.startswith('openindiana'):
        from .openindiana import openindiana
        return openindiana
    
    if name.startswith('openmamba'):
        from .openmamba import openmamba
        return openmamba
    
    if name.startswith('openmandriva'):
        from .openmandriva import openmandriva
        return openmandriva
    
    if name.startswith('openstage'):
        from .openstage import openstage
        return openstage
    
    if (name.startswith('wrt') or name.endswith('wrt')):
        from .wrt import wrt
        return wrt
    
    if name.startswith('open source media center') or name == 'osmc':
        from .open_source_media_center import open_source_media_center
        return open_source_media_center
    
    if name.startswith('opnsense'):
        from .opnsense import opnsense
        return opnsense
    
    if name.startswith('oracle'):
        from .oracle import oracle
        return oracle
    
    if name.startswith('orchid_small'):
        from .orchid_small import orchid_small
        return orchid_small
    
    if name.startswith('orchid'):
        from .orchid import orchid
        return orchid
    
    if name.startswith('os elbrus'):
        from .os_elbrus import os_elbrus
        return os_elbrus
    
    if name.startswith('pacbsd'):
        from .pacbsd import pacbsd
        return pacbsd
    
    if name.startswith('panwah'):
        from .panwah import panwah
        return panwah
    
    if name.startswith('parabola_small'):
        from .parabola_small import parabola_small
        return parabola_small
    
    if name.startswith('parabola'):
        from .parabola import parabola
        return parabola
    
    if name.startswith('pardus'):
        from .pardus import pardus
        return pardus
    
    if name.startswith('parrot'):
        from .parrot import parrot
        return parrot
    
    if name.startswith('parsix'):
        from .parsix import parsix
        return parsix
    
    if name.startswith('pcbsd') or name.startswith('trueos'):
        from .pcbsd import pcbsd
        return pcbsd
    
    if name.startswith('pclinuxos'):
        from .pclinuxos import pclinuxos
        return pclinuxos
    
    if name.startswith('pearos'):
        from .pearos import pearos
        return pearos
    
    if name.startswith('pengwin'):
        from .pengwin import pengwin
        return pengwin
    
    if name.startswith('peppermint'):
        from .peppermint import peppermint
        return peppermint
    
    if name.startswith('pisi'):
        from .pisi import pisi
        return pisi
    
    if name.startswith('pikaos'):
        from .pikaos import pikaos
        return pikaos
    
    if name.startswith('phyos'):
        from .phyos import phyos
        return phyos
    
    if name.startswith('pnm linux') or name.startswith('whpnm linux'):
        from .pnm_linux import pnm_linux
        return pnm_linux
    
    if name.startswith('popos_small') or name.startswith('pop_os_small'):
        from .popos_small import popos_small
        return popos_small
    
    if name.startswith('pop!_os') or name.startswith('popos') or name.startswith('pop_os'):
        from .pop__os import pop__os
        return pop__os
    
    if name.startswith('porteus'):
        from .porteus import porteus
        return porteus
    
    if name == 'postmarketos_small':
        from .postmarketos_small import postmarketos_small
        return postmarketos_small
    
    if name.startswith('postmarketos'):
        from .postmarketos import postmarketos
        return postmarketos
    
    if name.startswith('puffos'):
        from .puffos import puffos
        return puffos
    
    if name.startswith('proxmox'):
        from .proxmox import proxmox
        return proxmox
    
    if name.startswith('puppy') or name.startswith('quirky werewolf') or name.startswith('precise puppy'):
        from .puppy import puppy
        return puppy
    
    if name.startswith('pureos_small'):
        from .pureos_small import pureos_small
        return pureos_small
    
    if name.startswith('pureos'):
        from .pureos import pureos
        return pureos
    
    if name.startswith('peropesis'):
        from .peropesis import peropesis
        return peropesis
    
    if name.startswith('q4os'):
        from .q4os import q4os
        return q4os
    
    if name.startswith('qubes'):
        from .qubes import qubes
        return qubes
    
    if name.startswith('qubyt'):
        from .qubyt import qubyt
        return qubyt
    
    if name.startswith('quibian'):
        from .quibian import quibian
        return quibian
    
    if name.startswith('radix'):
        from .radix import radix
        return radix
    
    if name.startswith('raspbian_small'):
        from .raspbian_small import raspbian_small
        return raspbian_small
    
    if name.startswith('raspbian'):
        from .raspbian import raspbian
        return raspbian
    
    if name == 'ravynos':
        from .ravynos import ravynos
        return ravynos
    
    if name.startswith('reborn os') or name.startswith('reborn'):
        from .reborn_os import reborn_os
        return reborn_os
    
    if name.startswith('red star') or name.startswith('redstar'):
        from .red_star import red_star
        return red_star
    
    if name.startswith('redcore'):
        from .redcore import redcore
        return redcore
    
    if name == 'redhat_old' or name.startswith('rhel_old'):
        from .redhat_old import redhat_old
        return redhat_old
    
    if name.startswith('redhat') or name.startswith('red hat') or name.startswith('rhel'):
        from .redhat import redhat
        return redhat
    
    if name.startswith('refracted devuan') or name.startswith('refracted_devuan'):
        from .refracted_devuan import refracted_devuan
        return refracted_devuan
    
    if name.startswith('regata'):
        from .regata import regata
        return regata
    
    if name.startswith('regolith'):
        from .regolith import regolith
        return regolith
    
    if name.startswith('rhaymos'):
        from .rhaymos import rhaymos
        return rhaymos
    
    if name.startswith('rocky_small'):
        from .rocky_small import rocky_small
        return rocky_small
    
    if name.startswith('rocky'):
        from .rocky import rocky
        return rocky
    
    if name.startswith('rosa'):
        from .rosa import rosa
        return rosa
    
    if name.startswith('astra linux'):
        from .astra_linux import astra_linux
        return astra_linux
    
    if name.startswith('sabotage'):
        from .sabotage import sabotage
        return sabotage
    
    if name.startswith('sabayon'):
        from .sabayon import sabayon
        return sabayon
    
    if name.startswith('sailfish'):
        from .sailfish import sailfish
        return sailfish
    
    if name.startswith('salentos'):
        from .salentos import salentos
        return salentos
    
    if name.startswith('shastraos'):
        from .shastraos import shastraos
        return shastraos
    
    if name.startswith('sasanqua'):
        from .sasanqua import sasanqua
        return sasanqua
    
    if name.startswith('salient os') or name.startswith('salientos') or name.startswith('salientos'):
        from .salient_os import salient_os
        return salient_os
    
    if name.startswith('salix'):
        from .salix import salix
        return salix
    
    if name.startswith('scientific'):
        from .scientific import scientific
        return scientific
    
    if name.startswith('septor'):
        from .septor import septor
        return septor
    
    if name.startswith('serene'):
        from .serene import serene
        return serene
    
    if name.startswith('sharklinux'):
        from .sharklinux import sharklinux
        return sharklinux
    
    if name.startswith('siduction'):
        from .siduction import siduction
        return siduction
    
    if name.startswith('slackel'):
        from .slackel import slackel
        return slackel
    
    if name.startswith('slackware_small'):
        from .slackware_small import slackware_small
        return slackware_small
    
    if name.startswith('slackware'):
        from .slackware import slackware
        return slackware
    
    if name.startswith('slitaz'):
        from .slitaz import slitaz
        return slitaz
    
    if name.startswith('smartos'):
        from .smartos import smartos
        return smartos
    
    if name.startswith('skiffos'):
        from .skiffos import skiffos
        return skiffos
    
    if name.startswith('solus'):
        from .solus import solus
        return solus
    
    if name.startswith('sulin'):
        from .sulin import sulin
        return sulin
    
    if name.startswith('source mage') or name.startswith('source_mage'):
        from .source_mage import source_mage
        return source_mage
    
    if name.startswith('sparky'):
        from .sparky import sparky
        return sparky
    
    if name.startswith('star'):
        from .star import star
        return star
    
    if name.startswith('steamos'):
        from .steamos import steamos
        return steamos
    
    if name == 'sunos_small' or name == 'solaris_small':
        from .sunos_small import sunos_small
        return sunos_small
    
    if name == 'sunos' or name == 'solaris':
        from .sunos import sunos
        return sunos
    
    if name.startswith('opensuse leap') or name.startswith('opensuse_leap'):
        from .opensuse_leap import opensuse_leap
        return opensuse_leap
    
    if name.startswith('t2'):
        from .t2 import t2
        return t2
    
    if name.startswith('opensuse tumbleweed') or name.startswith('opensuse_tumbleweed'):
        from .opensuse_tumbleweed import opensuse_tumbleweed
        return opensuse_tumbleweed
    
    if name == 'opensuse_small' or name.startswith('suse_small'):
        from .opensuse_small import opensuse_small
        return opensuse_small
    
    if name.startswith('opensuse') or name.startswith('open suse') or name.startswith('suse'):
        from .opensuse import opensuse
        return opensuse
    
    if name.startswith('parch') or name.startswith('parch') or name.startswith('parch'):
        from .parch import parch
        return parch
    
    if name.startswith('swagarch'):
        from .swagarch import swagarch
        return swagarch
    
    if name.startswith('tails'):
        from .tails import tails
        return tails
    
    if name.startswith('torizoncore'):
        from .torizoncore import torizoncore
        return torizoncore
    
    if name.startswith('trisquel'):
        from .trisquel import trisquel
        return trisquel
    
    if name.startswith('twister'):
        from .twister import twister
        return twister
    
    if name.startswith('ubuntu cinnamon') or name.startswith('ubuntu-cinnamon'):
        from .ubuntu_cinnamon import ubuntu_cinnamon
        return ubuntu_cinnamon
    
    if name.startswith('ubuntu budgie') or name.startswith('ubuntu-budgie'):
        from .ubuntu_budgie import ubuntu_budgie
        return ubuntu_budgie
    
    if name.startswith('ubuntu-gnome'):
        from .ubuntu_gnome import ubuntu_gnome
        return ubuntu_gnome
    
    if name.startswith('ubuntu kylin') or name.startswith('ubuntu-kylin'):
        from .ubuntu_kylin import ubuntu_kylin
        return ubuntu_kylin
    
    if name.startswith('ubuntu touch'):
        from .ubuntu_touch import ubuntu_touch
        return ubuntu_touch
    
    if name.startswith('ubuntu mate') or name.startswith('ubuntu-mate'):
        from .ubuntu_mate import ubuntu_mate
        return ubuntu_mate
    
    if name == 'ubuntu_old02':
        from .ubuntu_old02 import ubuntu_old02
        return ubuntu_old02
    
    if name.startswith('ubuntu studio') or name == 'ubuntu-studio':
        from .ubuntu_studio import ubuntu_studio
        return ubuntu_studio
    
    if name.startswith('ubuntu sway') or name == 'ubuntu-sway':
        from .ubuntu_sway import ubuntu_sway
        return ubuntu_sway
    
    if name == 'ubuntu_small':
        from .ubuntu_small import ubuntu_small
        return ubuntu_small
    
    if name.startswith('ubuntu_old') or name.startswith('i3buntu'):
        from .ubuntu_old import ubuntu_old
        return ubuntu_old
    
    if name.startswith('floflis'):
        from .floflis import floflis
        return floflis
    
    if name.startswith('ubuntu'):
        from .ubuntu import ubuntu
        return ubuntu
    
    if name.startswith('ultramarine linux') or name.startswith('ultramarine'):
        from .ultramarine_linux import ultramarine_linux
        return ultramarine_linux
    
    if name.startswith('univalent'):
        from .univalent import univalent
        return univalent
    
    if name.startswith('uos'):
        from .uos import uos
        return uos
    
    if name.startswith('univention'):
        from .univention import univention
        return univention
    
    if name.startswith('uwuntu'):
        from .uwuntu import uwuntu
        return uwuntu
    
    if name.startswith('urukos'):
        from .urukos import urukos
        return urukos
    
    if name.startswith('venom_small'):
        from .venom_small import venom_small
        return venom_small
    
    if name.startswith('venom'):
        from .venom import venom
        return venom
    
    if name == 'void_small':
        from .void_small import void_small
        return void_small
    
    if name.startswith('void'):
        from .void import void
        return void
    
    if name.startswith('vnux'):
        from .vnux import vnux
        return vnux
    
    if name.startswith('vzlinux'):
        from .vzlinux import vzlinux
        return vzlinux
    
    if name.startswith('yiffos'):
        from .yiffos import yiffos
        return yiffos
    
    if name.startswith('semc'):
        from .semc import semc
        return semc
    
    if name.startswith('vanilla'):
        from .vanilla import vanilla
        return vanilla
    
    if name.startswith('obarun'):
        from .obarun import obarun
        return obarun
    
    if (name.startswith('wii-linux-ngx') or name.endswith('wii-linux-ngx')) or (name.startswith('whiite-linux') or name.endswith('whiite-linux')) or (name.startswith('gc-linux') or name.endswith('gc-linux')):
        from .wii_linux_ngx import wii_linux_ngx
        return wii_linux_ngx
    
    if (name.startswith('[windows 11]') or name.endswith('[windows 11]')) or (name.startswith('on windows 11') or name.endswith('on windows 11')) or name.startswith('windows 11') or name == 'windows11':
        from .windows_11 import windows_11
        return windows_11
    
    if (name.startswith('[windows 10]') or name.endswith('[windows 10]')) or (name.startswith('on windows 10') or name.endswith('on windows 10')) or name.startswith('windows 8') or name.startswith('windows 10') or name == 'windows10' or name == 'windows8':
        from .windows_10 import windows_10
        return windows_10
    
    if name == 'windows95':
        from .windows95 import windows95
        return windows95
    
    if name.startswith('windows'):
        from .windows import windows
        return windows
    
    if name.startswith('xray_os'):
        from .xray_os import xray_os
        return xray_os
    
    if name.startswith('xubuntu'):
        from .xubuntu import xubuntu
        return xubuntu
    
    if name.startswith('soda'):
        from .soda import soda
        return soda
    
    if name.startswith('krassos') or name.startswith('krass'):
        from .krassos import krassos
        return krassos
    
    if name.startswith('irix'):
        from .irix import irix
        return irix
    
    if name.startswith('xenia2'):
        from .xenia2 import xenia2
        return xenia2
    
    if name.startswith('xenia'):
        from .xenia import xenia
        return xenia
    
    if name.startswith('zorin'):
        from .zorin import zorin
        return zorin
    
    if name.endswith('bsd'):
        from .bsd import bsd
        return bsd
    
    if name == 'darwin':
        from .darwin import darwin
        return darwin
    
    if name.startswith('gnu'):
        from .gnu import gnu
        return gnu
    
    if name == 'linux':
        from .linux import linux
        return linux
    
    if name.startswith('profelis sambabox') or name.startswith('sambabox'):
        from .profelis_sambabox import profelis_sambabox
        return profelis_sambabox
    
    if name == 'sunos':
        from .sunos import sunos
        return sunos
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

gentoo = AsciiArt(match=r'''"Gentoo"*''', color='5 7', ascii=r"""
${c1}         -/oyddmdhs+:.
     -o${c2}dNMMMMMMMMNNmhy+${c1}-`
   -y${c2}NMMMMMMMMMMMNNNmmdhy${c1}+-
 `o${c2}mMMMMMMMMMMMMNmdmmmmddhhy${c1}/`
 om${c2}MMMMMMMMMMMN${c1}hhyyyo${c2}hmdddhhhd${c1}o`
.y${c2}dMMMMMMMMMMd${c1}hs++so/s${c2}mdddhhhhdm${c1}+`
 oy${c2}hdmNMMMMMMMN${c1}dyooy${c2}dmddddhhhhyhN${c1}d.
  :o${c2}yhhdNNMMMMMMMNNNmmdddhhhhhyym${c1}Mh
    .:${c2}+sydNMMMMMNNNmmmdddhhhhhhmM${c1}my
       /m${c2}MMMMMMNNNmmmdddhhhhhmMNh${c1}s:
    `o${c2}NMMMMMMMNNNmmmddddhhdmMNhs${c1}+`
  `s${c2}NMMMMMMMMNNNmmmdddddmNMmhs${c1}/.
 /N${c2}MMMMMMMMNNNNmmmdddmNMNdso${c1}:`
+M${c2}MMMMMMNNNNNmmmmdmNMNdso${c1}/-
yM${c2}MNNNNNNNmmmmmNNMmhs+/${c1}-`
/h${c2}MMNNNNNNNNMNdhs++/${c1}-`
`/${c2}ohdmmddhys+++/:${c1}.`
  `-//////:--.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

ubuntu_gnome = AsciiArt(match=r'''"Ubuntu-GNOME"*''', color='4 5 7 6', ascii=r"""
${c3}          ./o.
        .oooooooo
      .oooo```soooo
    .oooo`     `soooo
   .ooo`   ${c4}.o.${c3}   `\/ooo.
   :ooo   ${c4}:oooo.${c3}   `\/ooo.
    sooo    ${c4}`ooooo${c3}    \/oooo
     \/ooo    ${c4}`soooo${c3}    `ooooo
      `soooo    ${c4}`\/ooo${c3}    `soooo
${c4}./oo    ${c3}`\/ooo    ${c4}`/oooo.${c3}   `/ooo
${c4}`\/ooo.   ${c3}`/oooo.   ${c4}`/oooo.${c3}   ``
${c4}  `\/ooo.    ${c3}/oooo     ${c4}/ooo`
${c4}     `ooooo    ${c3}``    ${c4}.oooo
${c4}       `soooo.     .oooo`
         `\/oooooooooo`
            ``\/oo``
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

pengwin = AsciiArt(match=r'''"Pengwin"*''', color='5 5 13', ascii=r"""
${c3}                     ...`
${c3}                     `-///:-`
${c3}                       .+${c2}ssys${c3}/
${c3}                        +${c2}yyyyy${c3}o    ${c2}
${c2}                        -yyyyyy:
${c2}           `.:/+ooo+/:` -yyyyyy+
${c2}         `:oyyyyyys+:-.`syyyyyy:
${c2}        .syyyyyyo-`   .oyyyyyyo
${c2}       `syyyyyy   `-+yyyyyyy/`
${c2}       /yyyyyy+ -/osyyyyyyo/.
${c2}       +yyyyyy-  `.-:::-.`
${c2}       .yyyyyy-
${c3}        :${c2}yyyyy${c3}o
${c3}         .+${c2}ooo${c3}+
${c3}           `.::/:.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

frugalware = AsciiArt(match=r'''"Frugalware"*''', color='4 7 1', ascii=r"""
${c1}          `++/::-.`
         /o+++++++++/::-.`
        `o+++++++++++++++o++/::-.`
        /+++++++++++++++++++++++oo++/:-.``
       .o+ooooooooooooooooooosssssssso++oo++/:-`
       ++osoooooooooooosssssssssssssyyo+++++++o:
      -o+ssoooooooooooosssssssssssssyyo+++++++s`
      o++ssoooooo++++++++++++++sssyyyyo++++++o:
     :o++ssoooooo${c2}/-------------${c1}+syyyyyo+++++oo
    `o+++ssoooooo${c2}/-----${c1}+++++ooosyyyyyyo++++os:
    /o+++ssoooooo${c2}/-----${c1}ooooooosyyyyyyyo+oooss
   .o++++ssooooos${c2}/------------${c1}syyyyyyhsosssy-
   ++++++ssooooss${c2}/-----${c1}+++++ooyyhhhhhdssssso
  -s+++++syssssss${c2}/-----${c1}yyhhhhhhhhhhhddssssy.
  sooooooyhyyyyyh${c2}/-----${c1}hhhhhhhhhhhddddyssy+
 :yooooooyhyyyhhhyyyyyyhhhhhhhhhhdddddyssy`
 yoooooooyhyyhhhhhhhhhhhhhhhhhhhddddddysy/
-ysooooooydhhhhhhhhhhhddddddddddddddddssy
 .-:/+osssyyyysyyyyyyyyyyyyyyyyyyyyyyssy:
       ``.-/+oosysssssssssssssssssssssss
               ``.:/+osyysssssssssssssh.
                        `-:/+osyyssssyo
                                .-:+++`
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

grapheneos = AsciiArt(match=r'''"GrapheneOS"*''', color='7 4', ascii=r"""
${c1}                        B?
                        G~
                        G~&
                      G!^:^?#
                     &^.:::.J
    &PG&          #G5JJ7~^~?JY5B&          #PG
     B5JJPGJ77YG5JYP#   &&   &B5JYPGJ7?YG5JYP#
        &Y..::.:P&               &?..::.:G
         #!::::?                  B~::::J
           B~J#                     B!?#
            !P                       75
            !P                       75
            !5                       7Y
         &Y~:^!P                  &J~:^!P
         P..::.:B                 Y..::.:#
      #PYJJ~^^!JJYP#          &B5YJ?~^^!JJYG#
    &YYG#   &&   #PYJ5G5??JGGYJ5G&   &&   #PYP
                     B^.::..7&
                      J::::^G
                       #Y^G&
                        B~
                        G!
                        #
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

xenia2 = AsciiArt(match=r'''"Xenia2"*''', color='#55CDFD' '#F6AAB7' '#FFFFFF', ascii=r"""
${c2}      ,c.                       .c;
${c2}    .${c1}KMMMk${c2}....             ....${c1}kMMMK${c2}.
${c2}   .${c1}WMMMMMX${c2}.....         .....${c1}KMMMMMW.
${c1}   XMMMMMMM0${c2}.....        ....${c1}OMMMMMMMN
${c1}  dMMMMMMMMM;${c2}.... ..... ....,${c1}MMMMMMMMMd
${c1}  WMMMMMMMMMl;${c3}okKKKKKKKKKOo${c1};cMMMMMMMMMM
${c1} 'MMMMMMMNX${c2}K0${c3}KKKKKKKKKKKKKKK${c2}0K${c1}XNMMMMMMM;
${c1} oMMMMMMM${c2}Oxo${c3}KKKKKKKKKKKKKKKKK${c2}oxO${c1}MMMMMMMd
${c1} dMMMMMMM${c2}dxxx${c3}KKKKKKKKKKKKKKK${c2}xxxd${c1}NMMMMMMk
${c1} :MMMMX0${c2}xxxxxx${c3}0KKKKKKKK0KK0${c2}xxxxxx0${c1}XMMMMc
${c1}  MMMO${c2}xxxxxxxxdx${c3}kdd${c2}0x0${c3}ddk${c2}xdxxxxxxxx${c1}OMMM
${c1} ;${c2}xxkxddxxxxdodxxxxdxdxxxxdodxxxxddxkxx${c1};
${c1}dxd${c2}KMMMWXo${c1}'.....'${c2}cdxxxdc${c1}'.....'${c2}lXWMMMX${c1}dxd
${c1}cxd${c2}XMMMN${c1},..........${c2}dxd${c1}'.........'${c2}XMMMN${c1}dxl
${c1} .xx${c2}WMMl${c1}...''....'.;k:.'....''...${c2}lMMW${c1}xx.
${c1}..:kXMMx..'....''..kMk..''....'..xMMXkc..
${c1} dMMMMMMd.....'...xMMMx...''....dMMMMMMx
${c1}    kMMMMWOoc:coOkolllokOoc:coOWMMMMO
${c1}         .MMMMMMMMl${c2}...${c1}lNMMMMMMM.
${c1}            KMMMMMMX${c2}l${c1}KMMMMMMX
${c1}               .MMMMMMMMM.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

openmandriva = AsciiArt(match=r'''"OpenMandriva"*''', color='4', ascii=r"""
${c1}                  ``````
            `-:/+++++++//:-.`
         .:+++oooo+/:.``   ``
      `:+ooooooo+:.  `-:/++++++/:.`
     -+oooooooo:` `-++o+/::::://+o+/-
   `/ooooooooo-  -+oo/.`        `-/oo+.
  `+ooooooooo.  :os/`              .+so:
  +sssssssss/  :ss/                 `+ss-
 :ssssssssss`  sss`                  .sso
 ossssssssss  `yyo                    sys
`sssssssssss` `yys                   `yys
`sssssssssss:  +yy/                  +yy:
 oyyyyyyyyyys. `oyy/`              `+yy+
 :yyyyyyyyyyyo. `+yhs:.         `./shy/
  oyyyyyyyyyyys:` .oyhys+:----/+syhy+. `
  `syyyyyyyyyyyyo-` .:osyhhhhhyys+:``.:`
   `oyyyyyyyyyyyyys+-`` `.----.```./oo.
     /yhhhhhhhhhhhhhhyso+//://+osyhy/`
      `/yhhhhhhhhhhhhhhhhhhhhhhhhy/`
        `:oyhhhhhhhhhhhhhhhhhhyo:`
            .:+syhhhhhhhhys+:-`
                 ``....``
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

aster = AsciiArt(match=r'''"Aster"*''', color='6 6', ascii=r"""
${c1}                      ...''...
${c1}                 .;oOXWMWNXXXNMMN0d:.
${c1}              .oXMWOo;..       ..:oO;
${c1}            ;KMWx,       co,
${c1}          'KMNl         dMMW.
${c1}         oMMx          xMMMMk
${c1}        xMM:          dMMMMMM;
${c1}       cMMl          dMMMMMMMW
${c1}       NMK          xMMMx::dXMx
${c1}      ,MMl         xMMN'     .o.
${c1}      cMM;        dMMW'
${c1}      ;MMc       oMMW,
${c1}       WMK      dMMW,  ccccccc.
${c1}       lMMl    oMMM;   ooooooo.
${c1}        OMMc   ...
${c1}         xMMx
${c1}          ;XMN:
${c1}            ,.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

bitrig = AsciiArt(match=r'''"Bitrig"*''', color='2 7', ascii=r"""
${c1}   `hMMMMN+
   -MMo-dMd`
   oMN- oMN`
   yMd  /NM:
  .mMmyyhMMs
  :NMMMhsmMh
  +MNhNNoyMm-
  hMd.-hMNMN:
  mMmsssmMMMo
 .MMdyyhNMMMd
 oMN.`/dMddMN`
 yMm/hNm+./MM/
.dMMMmo.``.NMo
:NMMMNmmmmmMMh
/MN/-------oNN:
hMd.       .dMh
sm/         /ms
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

netbsd = AsciiArt(match=r'''"NetBSD"*''', color='5 7', ascii=r"""
${c1}                     `-/oshdmNMNdhyo+:-`
${c2}y${c1}/s+:-``    `.-:+oydNMMMMNhs/-``
${c2}-m+${c1}NMMMMMMMMMMMMMMMMMMMNdhmNMMMmdhs+/-`
 ${c2}-m+${c1}NMMMMMMMMMMMMMMMMMMMMmy+:`
  ${c2}-N/${c1}dMMMMMMMMMMMMMMMds:`
   ${c2}-N/${c1}hMMMMMMMMMmho:`
    ${c2}-N/${c1}-:/++/:.`
${c2}     :M+
      :Mo
       :Ms
        :Ms
         :Ms
          :Ms
           :Ms
            :Ms
             :Ms
              :Ms
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

almalinux = AsciiArt(match=r'''"AlmaLinux"*''', color='1 3 4 2 6', ascii=r"""
${c1}         'c:.
${c1}        lkkkx, ..       ${c2}..   ,cc,
${c1}        okkkk:ckkx'  ${c2}.lxkkx.okkkkd
${c1}        .:llcokkx'  ${c2}:kkkxkko:xkkd,
${c1}      .xkkkkdood:  ${c2};kx,  .lkxlll;
${c1}       xkkx.       ${c2}xk'     xkkkkk:
${c1}       'xkx.       ${c2}xd      .....,.
${c3}      .. ${c1}:xkl'     ${c2}:c      ..''..
${c3}    .dkx'  ${c1}.:ldl:'. ${c2}'  ${c4}':lollldkkxo;
${c3}  .''lkkko'                     ${c4}ckkkx.
${c3}'xkkkd:kkd.       ..  ${c5};'        ${c4}:kkxo.
${c3},xkkkd;kk'      ,d;    ${c5}ld.   ${c4}':dkd::cc,
${c3} .,,.;xkko'.';lxo.      ${c5}dx,  ${c4}:kkk'xkkkkc
${c3}     'dkkkkkxo:.        ${c5};kx  ${c4}.kkk:;xkkd.
${c3}       .....   ${c5}.;dk:.   ${c5}lkk.  ${c4}:;,
             ${c5}:kkkkkkkdoxkkx
              ,c,,;;;:xkkd.
                ;kkkkl...
                ;kkkkl
                 ,od;
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

kali_small = AsciiArt(match=r'''"kali_small" | "kalilinux_small" | "kali_linux_small"''', color='4 8', ascii=r"""
${c1}     -#. #
      @###
  -######
 @#########
=##.  .#####
##      ## ##
##       ## #
##       @###
##.        ###
 ##%       ##-
  -##%    -*
   :*##+
     :*#*
       -#
        @
        :
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

guix_small = AsciiArt(match=r'''"guix_small"*''', color='3 7 6 1 8', ascii=r"""
${c1}|.__          __.|
|__ \        / __|
   \ \      / /
    \ \    / /
     \ \  / /
      \ \/ /
       \__/
""")
    


from __future__ import annotations

import dataclasses
import inspect
import json
from datetime import datetime, date


class EnhancedJSONEncoder(json.JSONEncoder):
    """
    An improvement to the json.JSONEncoder class, which supports:
    encoding for dataclasses, encoding for datetime, and sets
    """

    def default(self, o: object) -> object:

        # Support encoding dataclasses
        # https://stackoverflow.com/a/51286749/7346633
        if dataclasses.is_dataclass(o):
            return dataclasses.asdict(o)

        # Support encoding datetime
        if isinstance(o, (datetime, date)):
            return o.isoformat()

        # Support for sets
        # https://stackoverflow.com/a/8230505/7346633
        if isinstance(o, set):
            return list(o)

        return super().default(o)


def json_stringify(obj: object, indent: int | None = None) -> str:
    """
    Serialize json string with support for dataclasses and datetime and sets and with custom
    configuration.
    Preconditions:
        - obj != None
    :param obj: Objects
    :param indent: Indent size or none
    :return: Json strings
    """
    return json.dumps(obj, indent=indent, cls=EnhancedJSONEncoder, ensure_ascii=False)


def from_dict(cls, d: dict):
    return cls(**{k: v for k, v in d.items() if k in inspect.signature(cls).parameters})



# This file is automatically generated. Please do not modify.

from . import AsciiArt

refracted_devuan = AsciiArt(match=r'''"Refracted Devuan"* | "Refracted_Devuan"*''', color='8 7', ascii=r"""
${c2}                             A
                            VW
                           VVW\
                         .yWWW\
 ,;,,u,;yy;;v;uyyyyyyy  ,WWWWW^
    *WWWWWWWWWWWWWWWW/  $VWWWWw      ,
        ^*%WWWWWWVWWX  $WWWW**    ,yy
        ,    "**WWW/' **'   ,yy/WWW*`
       &WWWWwy    `*`  <,ywWW%VWWW*
     yWWWWWWWWWW*    .,   "**WW%W
   ,&WWWWWM*"`  ,y/  &WWWww   ^*
  XWWX*^   ,yWWWW09 .WWWWWWWWwy,
 *`        &WWWWWM  WWWWWWWWWWWWWww,
           (WWWWW` /#####WWW***********
           ^WWWW
            VWW
            Wh.
            V/
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

hamonikr = AsciiArt(match=r'''"HamoniKR"*''', color='4 7 99 1 3 7', ascii=r"""
${c1}
                     cO0Ox.
                  .ldddddddo.
                .lddddddddddo
              'lddddddddddddc
            ,oddddddddddddd;
          'ldddddddddddddo.
        .oddddddddddddddc.
      ,dddddddddddddddo.
    ,ccoooooooocoddooo:
  ,cooooooooooooooooop ${c3}                 c000x.
${c1}.cooooooooooooooopcllll${c3}              .cddddddo.
${c1}coooooooooooooop' .qlll.${c3}           .ddoooooooo;
${c1}cooooooooooc;        ${c3}'qlllp.     .ddoooooooooo;
${c1}.cooooooc;             ${c3}'lllbc...coooooooooooo;
${c1}  .cooc'                ${c3}.llllcoooooooooooooo.
                         .coooooooooooooop:
                       .coooooooooooooop'
                      .cooooooooooooop.
                    .cooooooooooooop.
                   .coooooooooooop.
                  .cooooooooooop.
                  .cooooooooop.
                   .cooooop'
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

mageia = AsciiArt(match=r'''"Mageia"*''', color='6 7', ascii=r"""
${c1}        .°°.
         °°   .°°.
         .°°°. °°
         .   .
          °°° .°°°.
      .°°°.   '___'
${c2}     .${c1}'___'     ${c2}   .
   :dkxc;'.  ..,cxkd;
 .dkk. kkkkkkkkkk .kkd.
.dkk.  ';cloolc;.  .kkd
ckk.                .kk;
xO:                  cOd
xO:                  lOd
lOO.                .OO:
.k00.              .00x
 .k00;            ;00O.
  .lO0Kc;,,,,,,;c0KOc.
     ;d00KKKKKK00d;
        .,KKKK,.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

opensuse = AsciiArt(match=r'''"openSUSE"* | "open SUSE"* | "SUSE"*''', color='2 7', ascii=r"""
${c2}           .;ldkO0000Okdl;.
       .;d00xl:^''''''^:ok00d;.
     .d00l'                'o00d.
   .d0Kd'${c1}  Okxol:;,.          ${c2}:O0d.
  .OK${c1}KKK0kOKKKKKKKKKKOxo:,      ${c2}lKO.
 ,0K${c1}KKKKKKKKKKKKKKK0P^${c2},,,${c1}^dx:${c2}    ;00,
.OK${c1}KKKKKKKKKKKKKKKk'${c2}.oOPPb.${c1}'0k.${c2}   cKO.
:KK${c1}KKKKKKKKKKKKKKK: ${c2}kKx..dd ${c1}lKd${c2}   'OK:
dKK${c1}KKKKKKKKKOx0KKKd ${c2}^0KKKO' ${c1}kKKc${c2}   dKd
dKK${c1}KKKKKKKKKK;.;oOKx,..${c2}^${c1}..;kKKK0.${c2}  dKd
:KK${c1}KKKKKKKKKK0o;...^cdxxOK0O/^^'  ${c2}.0K:
 kKK${c1}KKKKKKKKKKKKK0x;,,......,;od  ${c2}lKk
 '0K${c1}KKKKKKKKKKKKKKKKKKKK00KKOo^  ${c2}c00'
  'kK${c1}KKOxddxkOO00000Okxoc;''   ${c2}.dKk'
    l0Ko.                    .c00l'
     'l0Kk:.              .;xK0l'
        'lkK0xl:;,,,,;:ldO0kl'
            '^:ldxkkkkxdl:^'
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

parch = AsciiArt(match=r'''"parch"* | "Parch"* | "PARCH"*''', color='4 7 1', ascii=r"""
${c1}                       ,:lodddd.
                   .:clooood.
                 ;clllooooc
               ;cclllllloo
              .cccccllllll
            .   ,cccclllll
           ':::;; ccccclll;
          .:::cccccccccccll;
          ;::::ccccllllllcll:
         .;::::cccclllloool::;
         ;;;::::cccclllolc::::;.
         ;;;::::cccclllccc:::::;.
         ;;;::::cccclccccc::::::;.
         ;;;;::::::llcccccc:::::'
         ;;;;:; ,clllccccccc::
         .;;  .cllllllcccccc::;::::'
             .'''''''''',:lddoooolll
            '.....'''',cdddooooollll
           ........':oddddoooolllllc
            ....';ldddddooooolllllc:
              ,cdddddddooooollllccc
               :ddddddoooolllllccc
                 ;ddooooolllllcc.
                    :ooollllc.
                        c'
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

dragonfly_small = AsciiArt(match=r'''"dragonfly_small"*''', color='1 7 3', ascii=r"""
${c2}   ,${c1}_${c2},
('-_${c1}|${c2}_-')
 >--${c1}|${c2}--<
(_-'${c1}|${c2}'-_)
    ${c1}|
    |
    |
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

pearos = AsciiArt(match=r'''"pearOS"*''', color='2 3 1 1 5 4', ascii=r"""
\e[0;32m                  .+yh
                 sMMMo
                sMMN+
                +o:    \e[0m
\e[93m           ./oyyys+.
         :dMMMMMMMMMm/
        :MMMMMMMMMMMMMy
        yMMMMMMMMMMMMMN \e[0m
\e[31m        mMMMMMMMMMMMMs`
       yMMMMMMMMMMMMo
     -mMMMMMMMMMMMMM`
    oMMMMMMMMMMMMMMM` \e[0m
\e[95m   oMMMMMMMMMMMMMMMMy
  .MMMMMMMMMMMMMMMMMMy`
  +MMMMMMMMMMMMMMMMMMMMy/`
  /MMMMMMMMMMMMMMMMMMMMMMMNds \e[0m
\e[34m  `mMMMMMMMMMMMMMMMMMMMMMMMM/
   .mMMMMMMMMMMMMMMMMMMMMMM+
    `oNMMMMMMMMMMMMMMMMMMd-
      `+hMMMMMMMMMMMMMms-
          -/osyhhyso:. \e[0m
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

deepin = AsciiArt(match=r'''"Deepin"*''', color='2 7', ascii=r"""
${c1}             ............
         .';;;;;.       .,;,.
      .,;;;;;;;.       ';;;;;;;.
    .;::::::::'     .,::;;,''''',.
   ,'.::::::::    .;;'.          ';
  ;'  'cccccc,   ,' :: '..        .:
 ,,    :ccccc.  ;: .c, '' :.       ,;
.l.     cllll' ., .lc  :; .l'       l.
.c       :lllc  ;cl:  .l' .ll.      :'
.l        'looc. .   ,o:  'oo'      c,
.o.         .:ool::coc'  .ooo'      o.
 ::            .....   .;dddo      ;c
  l:...            .';lddddo.     ,o
   lxxxxxdoolllodxxxxxxxxxc      :l
    ,dxxxxxxxxxxxxxxxxxxl.     'o,
      ,dkkkkkkkkkkkkko;.    .;o;
        .;okkkkkdl;.    .,cl:.
            .,:cccccccc:,.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

pardus = AsciiArt(match=r'''"Pardus"*''', color='3 7 6 1 8', ascii=r"""
${c1} .smNdy+-    `.:/osyyso+:.`    -+ydmNs.
/Md- -/ymMdmNNdhso/::/oshdNNmdMmy/. :dM/
mN.     oMdyy- -y          `-dMo     .Nm
.mN+`  sMy hN+ -:             yMs  `+Nm.
 `yMMddMs.dy `+`               sMddMMy`
   +MMMo  .`  .                 oMMM+
   `NM/    `````.`    `.`````    +MN`
   yM+   `.-:yhomy    ymohy:-.`   +My
   yM:          yo    oy          :My
   +Ms         .N`    `N.      +h sM+
   `MN      -   -::::::-   : :o:+`NM`
    yM/    sh   -dMMMMd-   ho  +y+My
    .dNhsohMh-//: /mm/ ://-yMyoshNd`
      `-ommNMm+:/. oo ./:+mMNmmo:`
     `/o+.-somNh- :yy: -hNmos-.+o/`
    ./` .s/`s+sMdd+``+ddMs+s`/s. `/.
        : -y.  -hNmddmNy.  .y- :
         -+       `..`       +-
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

aeros = AsciiArt(match=r'''"aerOS"*''', color='fg 0 0 0', ascii=r"""
${c1}
                   ooo OOO OOO ooo
               oOO                 OOo
           oOO                         OOo
        oOO                               OOo
      oOO                                   OOo
    oOO                                       OOo
   oOO                                         OOo
                                                OOo
                                                 OOo
                                                 OOo
                                                 OOo
                                                 OOo
                                                 OOo
  oOO                                           OOo
   oOO                                         OOo
    oOO                                       OOo
      oOO                                   OOo
        oO                                OOo
           oOO                         OOo
               oOO                 OOo
                   ooo OOO OOO ooo
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

opensuse_tumbleweed = AsciiArt(match=r'''"openSUSE Tumbleweed"* | "openSUSE_Tumbleweed"*''', color='2 7', ascii=r"""
${c2}                                     ......
     .,cdxxxoc,.               .:kKMMMNWMMMNk:.
    cKMMN0OOOKWMMXo. A        ;0MWk:'      ':OMMk.
  ;WMK;'       'lKMMNM,     :NMK'             'OMW;
 cMW;             WMMMN   ,XMK'                 oMM.
.MMc             ''^*~l. xMN:                    KM0
'MM.                   .NMO                      oMM
.MM,                 .kMMl                       xMN
 KM0               .kMM0' .dl>~,.               .WMd
 'XM0.           ,OMMK'    OMMM7'              .XMK
   *WMO:.    .;xNMMk'       NNNMKl.          .xWMx
     ^ONMMNXMMMKx;          V  'xNMWKkxllox0NMWk'
         '''''                    ':dOOXXKOxl'
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

pureos_small = AsciiArt(match=r'''"pureos_small"*''', color='2 7 7', ascii=r"""
${c1} _____________
|  _________  |
| |         | |
| |         | |
| |_________| |
|_____________|
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

radix = AsciiArt(match=r'''"Radix"*''', color='1 2', ascii=r"""
${c2}                .:oyhdmNo
             `/yhyoosdms`
            -o+/ohmmho-
           ..`.:/:-`
     `.--:::-.``${c1}
  .+ydNMMMMMMNmhs:`
`omMMMMMMMMMMMMMMNh-
oNMMMNmddhhyyhhhddmy.
mMMMMNmmddhhysoo+/:-`
yMMMMMMMMMMMMMMMMNNh.
-dmmmmmNNMMMMMMMMMMs`
 -+oossyhmMMMMMMMMd-
 `sNMMMMMMMMMMMMMm:
  `yMMMMMMNmdhhhh:
   `sNMMMMMNmmho.
    `+mMMMMMMMy.
      .yNMMMm+`
       `:yd+.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

linspire = AsciiArt(match=r'''"Linspire"* | "Freespire"* | "Lindows"*''', color='4 2', ascii=r"""
${c2}                                                   __^
${c2}                                                __/    \
${c2}   MMy        dMy                            __/        \
${c2}  dMMy        MMy                            ${c1}MM${c2}          \
${c2}  MMMy            ,,        ${c1}dMMMMn                        ${c2}\
${c2} dMMy        dMM dMMMMMMy  ${c1}dMM  MM dMMMMMy  dMM MM.nMMM dMMMMMM
${c1}MMM          ${c2}MMy MMy  MMy ${c1}dMM      MMy  MMy MMy MMy    dy   dMy
${c1}MMM         ${c2}dMM dMM   MMy  ${c1}dMMMMy dMM  dMM dMM dMM    dMMMMMMM
${c2} dMMy       MMy MMy  MMy     ${c1}dMMy MM  MMy MMy  MMy    dMM
${c2}dMMy       dMM dMM  dMM ${c1}dMM  MMy dMMMMMy dMM  dMM     MMy   MM
${c2}MMMMMMMMMM MMy MMy  MMy ${c1}dMMMyyy MMy     MMy  MMy      dMMMMMMy
${c2}                                ${c1}dy
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

xray_os = AsciiArt(match=r'''"Xray_OS"*''', color='15 14 16 24', ascii=r"""
${c1}               ${c1}rrrrrraaaaaaaaaaaayyyy
           ${c1}xxrrrrrrrraaaaaaaaaaaayyyyyyyyy
        ${c1}xxxxxrrrrrrrraaaaaaaaaaaayyyyyyy${c3}yyyyy${c2}yyyyyyyyyy
      ${c1}xxxxxxxrrrrrrrraaaaa ${c2}aaaaayyyyyyyyyyyyyyyyyyy
    ${c1}xxxxxx${c3}xxx${c1}rrrrrrrraaaa ${c2}aaaaaaayyyyyyyyyyyyyyyyy
  ${c1}xxxxxx${c3}xxxxxr${c1}rrrrrrraa ${c2}aaaaaaaaay${c3}yyyyyyyyy${c2}yyyy ${c1}yy
 ${c1}xxxxxxx${c3}xxx${c1}xxrrrrrrrra ${c2}aaaaaaaaa${c3}ayyyyyyyyyyyy${c1}yyyyyy
 ${c1}xxxxxxxxxxxxrrrrrrrr ${c2}aaaaaaaaaaa${c3}yyyyyyyyyyyy${c1}yyyyyyy
${c1}xxxxxxxxxxxxxrrrrrr ${c2}raaaaaaaaaaaayyy${c3}yyyyyyyy${c1}yyyyyy${c1}yyy
${c1}xxxxxxxxxxxxxrrrrr ${c2}rraaaaaaaaaaaayyyyy${c3}yy${c2}yyyyyy ${c1}yyyyyy
${c1}xxxxxxxx${c3}xxxx${c1}xrrrrr${c2}rr${c3}raaaaaaa${c2}aaaaayyyyyyyyyy ${c1}yyyyyyyyy
${c1}xxxxxxx${c3}xxxx${c1}xxrrrrrrr${c3}raaaaaa${c2}aaaaaayyyyyyy ${c1}yyyyyyyyyyyy
${c1}xxxxxxx${c3}xxx${c1}xxxrrrrrrrr${c3}aaaaaa${c2}aaaaaayyyy ${c1}yyyyyyyyyyyyyy
 ${c1}xxxxxxxxxxxxrrrrrrrra ${c2}aaaaaaaaaay ${c1}yyyyyyyyyyyyyyyy
  ${c1}xxxxxxxxxxxrrrrrrr ${c2}aaaaaaaaaaaayyyy${c1}yyyyyyyyyyyyy
   ${c1}xxxxxxx${c3}xxxrr${c1}rrrr ${c2}raaaaaaaaaaaa ${c1}yyyyyyyyyyyyyyy
     ${c1}xxxxxxxxrrrr ${c2}rrraaaaaaaaa ${c1}aayyyyyyyyyyyyyy
       ${c1}xxxxxxrrrrrrr ${c2}aaaaaa  ${c1}aaaayyyyyyyyyyyy
          ${c1}xxxrrrrrr ${c2}raaa  ${c1}aaaaaaayyyyyyyyy
              ${c1}rrrr ${c2}rr  ${c1}aaaaaaaaaayyyyyy
                 ${c2}r   ${c1}aaaaaaaaaa
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

netrunner = AsciiArt(match=r'''"Netrunner"*''', color='4 7 1', ascii=r"""
${c1}           .:oydmMMMMMMmdyo:`
        -smMMMMMMMMMMMMMMMMMMds-
      +mMMMMMMMMMMMMMMMMMMMMMMMMd+
    /mMMMMMMMMMMMMMMMMMMMMMMMMMMMMm/
  `hMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMy`
 .mMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMd`
 dMMMMMMMMMMMMMMMMMMMMMMNdhmMMMMMMMMMMh
+MMMMMMMMMMMMMNmhyo+/-.   -MMMMMMMMMMMM/
mMMMMMMMMd+:.`           `mMMMMMMMMMMMMd
MMMMMMMMMMMdy/.          yMMMMMMMMMMMMMM
MMMMMMMMMMMMMMMNh+`     +MMMMMMMMMMMMMMM
mMMMMMMMMMMMMMMMMMs    -NMMMMMMMMMMMMMMd
+MMMMMMMMMMMMMMMMMN.  `mMMMMMMMMMMMMMMM/
 dMMMMMMMMMMMMMMMMMy  hMMMMMMMMMMMMMMMh
 `dMMMMMMMMMMMMMMMMM-+MMMMMMMMMMMMMMMd`
  `hMMMMMMMMMMMMMMMMmMMMMMMMMMMMMMMMy
    /mMMMMMMMMMMMMMMMMMMMMMMMMMMMMm:
      +dMMMMMMMMMMMMMMMMMMMMMMMMd/
        -odMMMMMMMMMMMMMMMMMMdo-
           `:+ydmNMMMMNmhy+-`
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

cyberos = AsciiArt(match=r'''"CyberOS"*''', color='50 32 57', ascii=r"""
${c3}             !M$EEEEEEEEEEEP
            .MMMMM000000Nr.
            ${c3}&MMMMMM${c2}MMMMMMMMMMMMM9
           ${c3}~MMM${c1}MMMM${c2}MMMMMMMMMMMMC
      ${c1}"    ${c3}M${c1}MMMMMMM${c2}MMMMMMMMMMs
    ${c1}iM${c2}MMM&&${c1}MMMMMMMM${c2}MMMMMMMM\
   ${c1}BMMM${c2}MMMMM${c1}MMMMMMM${c2}MMMMMM${c3}"
  ${c1}9MMMMM${c2}MMMMMMM${c1}MMMM${c2}MMMM${c3}MMMf-
        ${c2}sMMMMMMMM${c1}MM${c2}M${c3}MMMMMMMMM3_
         ${c2}+ffffffff${c1}P${c3}MMMMMMMMMMMM0
                    ${c2}CMMMMMMMMMMM
                      }MMMMMMMMM
                        ~MMMMMMM
                          "RMMMM
                            .PMB
""")
    


# Start the server with:
#
# uvicorn tools.gh_moderator:app --reload --port 59523
#
# pip install openai pygithub fastapi uvicorn hypy_utils

import hashlib
import hmac
import json
import unicodedata
from datetime import datetime
from pathlib import Path

import openai
import tomllib as toml
from fastapi import FastAPI, Request, Response
from github import Github
from hypy_utils import write, json_stringify
from hypy_utils.logging_utils import setup_logger
from openai.openai_object import OpenAIObject

from hyfetch.color_util import printc

log = setup_logger()


def read_config():
    with open(Path.home() / ".config/gh_moderator.toml", "rb") as f:
        return toml.load(f)


app = FastAPI()
config = read_config()
webhook_secret = bytes(config["webhook_secret"], "utf-8")

gh = Github(per_page=100, login_or_token=config["gh_token"])
me = gh.get_user()
repo = gh.get_repo(config["gh_repo"])
printc(f"&a[+] Logged in as {me.login}")

harm_classifier_url, harm_classifier_token = config["harm_classifier_url"], config["harm_classifier_token"]

script_path = Path(__file__).parent
supported_events = ["issue_comment", "issues", "pull_request", "pull_request_review_comment"]
ai_notice = f"If you think this is a false-positive, please contact the owner of this repo."

openai.organization = config['OpenAI']['org']
openai.api_key = config['OpenAI']['key']
openai_model = config['OpenAI']['model']


def get_content(event: str, obj: dict) -> str:
    # Get the content of the event
    match event:
        case "issue_comment" | "pull_request_review_comment":
            return obj["comment"]["body"]
        case "issues":
            return obj["issue"]["title"] + "\n\n" + obj["issue"]["body"]
        case "pull_request":
            return obj["pull_request"]["title"] + "\n\n" + obj["pull_request"]["body"]


def redact(event: str, obj: dict, id: str, reason: str):
    """
    Redact the event
    """
    printc(f"&c[!] Redacting {event} {id} for {reason}.")
    tail = f"\n\n> Reason: {reason}\n> {ai_notice}"
    redact_notice = f"[Redacted by [AI Content Moderator]({me.html_url})]{tail}"

    match event:
        case "issue_comment":
            # Redact the comment
            comment = repo.get_issue(obj["issue"]["number"]).get_comment(obj["comment"]["id"])
            comment.edit(body=redact_notice)

        case "pull_request_review_comment":
            # Redact the comment
            comment = repo.get_pull(obj["pull_request"]["number"]).get_review_comment(obj["comment"]["id"])
            comment.edit(body=redact_notice)

        case "issues" | "pull_request":
            # Close the issue
            iss = repo.get_issue(obj["issue"]["number"])
            iss.edit(title="[Redacted]", body=redact_notice, state="closed")
            iss.create_comment(f"Issue closed for potentially offensive content.{tail}")
            iss.lock("spam")


async def process_event(event: str, obj: dict, id: str):
    # Preliminary checks
    if event not in supported_events:
        printc(f"&7[-] Unknown event: {event}")
        return

    if obj['repository']['full_name'] != repo.full_name:
        printc(f"&7[-] Unknown repository: {obj['repository']['full_name']}")
        return

    blacklist_users = {v for v in (script_path / "blacklist_users.csv").read_text().split("\n") if v}
    actor = obj["sender"]["login"]
    if actor == me.login:
        printc(f"&7[-] Ignoring event by myself: {id} {event} by {actor}")
        return
    printc(f"&e[+] Received event: {id} {event} by {actor}")

    if actor in blacklist_users:
        redact(event, obj, id, "User is blacklisted")
        return

    # Normalize content
    content = unicodedata.normalize("NFKC", get_content(event, obj))

    # Ask OpenAI to predict if it's offensive
    res: OpenAIObject = openai.Moderation.create(content, openai_model).results[0]
    write(f"moderator-data/openai/{id}.json", json_stringify(res))
    if res.flagged:
        printc(f"\n&c[!] AI classified {event} {id} by {actor} as offensive !!!\n> Content: {content}\n\n")
        reason = " | ".join(f"{k} {res.category_scores.get(k) * 100:.0f}%" for k, v in res.categories.items() if v)
        redact(event, obj, id, f"Flagged by OpenAI : {reason}")
        return

    printc(f"&a[~] AI classified {event} {id} by {actor} as safe.")


@app.post("/")
async def handle_webhook(request: Request, response: Response):
    # Read headers
    event = request.headers.get("X-GitHub-Event")
    signature = request.headers.get("X-Hub-Signature")

    # Verify the signature
    body = await request.body()
    if not verify_signature(signature, body):
        response.status_code = 401
        return {"message": "Invalid signature"}

    # Parse the event body
    obj = json.loads(body.decode())

    # Log the request
    id = datetime.now().isoformat()
    write(f"moderator-data/webhook/{id}-{event}.json", json_stringify(obj, indent=4))

    await process_event(event, obj, id)

    return {"message": "OK"}


# Helper function to verify the signature
def verify_signature(signature: str, payload: bytes) -> bool:
    hash_type, signature = signature.split("=")
    digest = hmac.new(webhook_secret, msg=payload, digestmod=getattr(hashlib, hash_type)).hexdigest()
    return hmac.compare_digest(digest, signature)




# This file is automatically generated. Please do not modify.

from . import AsciiArt

freebsd_small = AsciiArt(match=r'''"freebsd_small"''', color='1 7 3', ascii=r"""
${c1}/\,-'''''-,/\
\_)       (_/
|           |
|           |
 ;         ;
  '-_____-'
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

siduction = AsciiArt(match=r'''"Siduction"*''', color='4 4', ascii=r"""
${c1}                _aass,
               jQh: =$w
               QWmwawQW
               )$QQQQ@(   ..
         _a_a.   ~??^  syDY?Sa,
       _mW>-<$c       jWmi  imm.
       ]QQwayQE       4QQmgwmQQ`
        ?WWQWP'       -9QQQQQ@'._aas,
 _a%is.        .adYYs,. -"?!` aQB*~^3$c
_Qh;.nm       .QWc. {QL      ]QQp;..vmQ/
"QQmmQ@       -QQQggmQP      ]QQWmggmQQ(
 -???"         "$WQQQY`  __,  ?QQQQQQW!
        _yZ!?q,   -   .yWY!!Sw, "???^
       .QQa_=qQ       mQm>..vmm
        $QQWQQP       $QQQgmQQ@
         "???"   _aa, -9WWQQWY`
               _mB>~)$a  -~~
               mQms_vmQ.
               ]WQQQQQP
                -?T??"
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

kubuntu = AsciiArt(match=r'''"Kubuntu"*''', color='4 7 1', ascii=r"""
${c1}           `.:/ossyyyysso/:.
        .:oyyyyyyyyyyyyyyyyyyo:`
      -oyyyyyyyo${c2}dMMy${c1}yyyyyyysyyyyo-
    -syyyyyyyyyy${c2}dMMy${c1}oyyyy${c2}dmMMy${c1}yyyys-
   oyyys${c2}dMy${c1}syyyy${c2}dMMMMMMMMMMMMMy${c1}yyyyyyo
 `oyyyy${c2}dMMMMy${c1}syysoooooo${c2}dMMMMy${c1}yyyyyyyyo`
 oyyyyyy${c2}dMMMMy${c1}yyyyyyyyyyys${c2}dMMy${c1}sssssyyyo
-yyyyyyyy${c2}dMy${c1}syyyyyyyyyyyyyys${c2}dMMMMMy${c1}syyy-
oyyyysoo${c2}dMy${c1}yyyyyyyyyyyyyyyyyy${c2}dMMMMy${c1}syyyo
yyys${c2}dMMMMMy${c1}yyyyyyyyyyyyyyyyyysosyyyyyyyy
yyys${c2}dMMMMMy${c1}yyyyyyyyyyyyyyyyyyyyyyyyyyyyy
oyyyyysos${c2}dy${c1}yyyyyyyyyyyyyyyyyy${c2}dMMMMy${c1}syyyo
-yyyyyyyy${c2}dMy${c1}syyyyyyyyyyyyyys${c2}dMMMMMy${c1}syyy-
 oyyyyyy${c2}dMMMy${c1}syyyyyyyyyyys${c2}dMMy${c1}oyyyoyyyo
 `oyyyy${c2}dMMMy${c1}syyyoooooo${c2}dMMMMy${c1}oyyyyyyyyo
   oyyysyyoyyyys${c2}dMMMMMMMMMMMy${c1}yyyyyyyo
    -syyyyyyyyy${c2}dMMMy${c1}syyy${c2}dMMMy${c1}syyyys-
      -oyyyyyyy${c2}dMMy${c1}yyyyyysosyyyyo-
        ./oyyyyyyyyyyyyyyyyyyo/.
           `.:/oosyyyysso/:.`
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

stock_linux = AsciiArt(match=r'''"Stock Linux"*''', color='4 7', ascii=r"""
${c1}

              #G5J5G#
          &BPYJJJJJJJYPB&
      &#G5JJJJJJY5YJJJJJJ5G#&
   #G5YJJJJJY5G#& &#G5YJJJJJY5G#
BPYJJJJJJJ5B&         &BPYJJJJJJYPB
JJJJJJJJJJY5G#&           &BPYJJJJJ
JJJJJJJJJJJJJJY5G#           &JJJJJ
PYJJJJJJJJJJJJJJJJYPB&        GYJJJ
  &BPYJJJJJJJJJJJJJJJJ5PB&      &BP
      #G5YJJJJJJJJJJJJJJJY5G#
PB&      &BP5JJJJJJJJJJJJJJJJYPB&
JJJYG        &BPYJJJJJJJJJJJJJJJJYP
JJJJJ&           #G5YJJJJJJJJJJJJJJ
JJJJJYPB&           &#G5YJJJJJJJJJJ
BPYJJJJJJYPB&         &B5JJJJJJJYPB
   #G5YJJJJJY5G#& &#G5YJJJJJY5G#
      &#G5JJJJJJY5YJJJJJJ5G#&
          &BPYJJJJJJJYPB&
              #G5J5G#
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

parabola_small = AsciiArt(match=r'''"parabola_small"*''', color='5 7', ascii=r"""
${c1}  __ __ __  _
.`_//_//_/ / `.
          /  .`
         / .`
        /.`
       /`
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

apricity = AsciiArt(match=r'''"Apricity"*''', color='4 7 1', ascii=r"""
${c2}                                    ./o-
          ``...``              `:. -/:
     `-+ymNMMMMMNmho-`      :sdNNm/
   `+dMMMMMMMMMMMMMMMmo` sh:.:::-
  /mMMMMMMMMMMMMMMMMMMMm/`sNd/
 oMMMMMMMMMMMMMMMMMMMMMMMs -`
:MMMMMMMMMMMMMMMMMMMMMMMMM/
NMMMMMMMMMMMMMMMMMMMMMMMMMd
MMMMMMMmdmMMMMMMMMMMMMMMMMd
MMMMMMy` .mMMMMMMMMMMMmho:`
MMMMMMNo/sMMMMMMMNdy+-.`-/
MMMMMMMMMMMMNdy+:.`.:ohmm:
MMMMMMMmhs+-.`.:+ymNMMMy.
MMMMMM/`.-/ohmNMMMMMMy-
MMMMMMNmNNMMMMMMMMmo.
MMMMMMMMMMMMMMMms:`
MMMMMMMMMMNds/.
dhhyys+/-`
""")
    


from . import main
from .color_util import printc

if __name__ == '__main__':
    try:
        main.run()
    except KeyboardInterrupt:
        printc('&cThe program is interrupted by ^C, exiting...')
        exit(0)


# This file is automatically generated. Please do not modify.

from . import AsciiArt

swagarch = AsciiArt(match=r'''"SwagArch"*''', color='4 7 1', ascii=r"""
${c2}        .;ldkOKXXNNNNXXK0Oxoc,.
   ,lkXMMNK0OkkxkkOKWMMMMMMMMMM;
 'K0xo  ..,;:c:.     `'lKMMMMM0
     .lONMMMMMM'         `lNMk'
${c2}    ;WMMMMMMMMMO.              ${c1}....::...
${c2}    OMMMMMMMMMMMMKl.       ${c1}.,;;;;;ccccccc,
${c2}    `0MMMMMMMMMMMMMM0:         ${c1}.. .ccccccc.
${c2}      'kWMMMMMMMMMMMMMNo.   ${c1}.,:'  .ccccccc.
${c2}        `c0MMMMMMMMMMMMMN,${c1},:c;    :cccccc:
${c2} ckl.      `lXMMMMMMMMMX${c1}occcc:.. ;ccccccc.
${c2}dMMMMXd,     `OMMMMMMWk${c1}ccc;:''` ,ccccccc:
${c2}XMMMMMMMWKkxxOWMMMMMNo${c1}ccc;     .cccccccc.
${c2} `':ldxO0KXXXXXK0Okdo${c1}cccc.     :cccccccc.
                    :ccc:'     `cccccccc:,
                                   ''
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

peppermint = AsciiArt(match=r'''"Peppermint"*''', color='1 15 3', ascii=r"""
${c1}               PPPPPPPPPPPPPP
${c1}           PPPP${c2}MMMMMMM${c1}PPPPPPPPPPP
${c1}         PPPP${c2}MMMMMMMMMM${c1}PPPPPPPP${c2}MM${c1}PP
${c1}       PPPPPPPP${c2}MMMMMMM${c1}PPPPPPPP${c2}MMMMM${c1}PP
${c1}     PPPPPPPPPPPP${c2}MMMMMM${c1}PPPPPPP${c2}MMMMMMM${c1}PP
${c1}    PPPPPPPPPPPP${c2}MMMMMMM${c1}PPPP${c2}M${c1}P${c2}MMMMMMMMM${c1}PP
${c1}   PP${c2}MMMM${c1}PPPPPPPPPP${c2}MMM${c1}PPPPP${c2}MMMMMMM${c1}P${c2}MM${c1}PPPP
${c1}   P${c2}MMMMMMMMMM${c1}PPPPPP${c2}MM${c1}PPPPP${c2}MMMMMM${c1}PPPPPPPP
${c1}  P${c2}MMMMMMMMMMMM${c1}PPPPP${c2}MM${c1}PP${c2}M${c1}P${c2}MM${c1}P${c2}MM${c1}PPPPPPPPPPP
${c1}  P${c2}MMMMMMMMMMMMMMMM${c1}PP${c2}M${c1}P${c2}MMM${c1}PPPPPPPPPPPPPPPP
${c1}  P${c2}MMM${c1}PPPPPPPPPPPPPPPPPPPPPPPPPPPPPP${c2}MMMMM${c1}P
${c1}  PPPPPPPPPPPPPPPP${c2}MMM${c1}P${c2}M${c1}P${c2}MMMMMMMMMMMMMMMM${c1}PP
${c1}  PPPPPPPPPPP${c2}MM${c1}P${c2}MM${c1}PPPP${c2}MM${c1}PPPPP${c2}MMMMMMMMMMM${c1}PP
${c1}   PPPPPPPP${c2}MMMMMM${c1}PPPPP${c2}MM${c1}PPPPPP${c2}MMMMMMMMM${c1}PP
${c1}   PPPP${c2}MM${c1}P${c2}MMMMMMM${c1}PPPPPP${c2}MM${c1}PPPPPPPPPP${c2}MMMM${c1}PP
${c1}    PP${c2}MMMMMMMMM${c1}P${c2}M${c1}PPPP${c2}MMMMMM${c1}PPPPPPPPPPPPP
${c1}     PP${c2}MMMMMMM${c1}PPPPPPP${c2}MMMMMM${c1}PPPPPPPPPPPP
${c1}       PP${c2}MMMM${c1}PPPPPPPPP${c2}MMMMMMM${c1}PPPPPPPP
${c1}         PP${c2}MM${c1}PPPPPPPP${c2}MMMMMMMMMM${c1}PPPP
${c1}           PPPPPPPPPP${c2}MMMMMMMM${c1}PPPP
${c1}               PPPPPPPPPPPPPP
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

xubuntu = AsciiArt(match=r'''"Xubuntu"*''', color='4 7 1', ascii=r"""
${c1}           `.:/ossyyyysso/:.
        `.yyyyyyyyyyyyyyyyyyyy.`
      `yyyyyyyyyyyyyyyyyyyyyyyyyy`
    `yyyyyyyyyyyyyyyyyyyy${c2}::${c1}yyyyyyyy`
   .yyyyyyyyyyy${c2}/+:${c1}yyyyyyy${c2}ds${c1}yyy${c2}+y${c1}yyyy.
  yyyyyyy${c2}:o/${c1}yy${c2}dMMM+${c1}yyyyy${c2}/M+${c1}y${c2}:hM+${c1}yyyyyy
 yyyyyyy${c2}+MMMy${c1}y${c2}mMMMh${c1}yyyyy${c2}yM::mM+${c1}yyyyyyyy
`yyyyyyy${c2}+MMMMysMMMd${c1}yyyyy${c2}dh:mN+${c1}yyyyyyyyy`
yyyyyyyy${c2}:NMMMMmMMMMmmdhyy+/y:${c1}yyyyyyyyyyy
yyyyyyyy${c2}+MMMMMMMMMMMMMMMMMMNho:${c1}yyyyyyyyy
yyyyyyyy${c2}mMMMMMMMMMMMMMMMMMMMMMMy${c1}yyyyyyyy
yyyyyyy${c2}+MMMMMMMMMMMMMMMMMMMMMMMM/${c1}yyyyyyy
`yyyyyy${c2}sMMMMMMMMMMMMMMMMMMMMMMmo${c1}yyyyyyy`
 yyyyyy${c2}oMMMMMMMMMMMMMMMMMMMmy+${c1}yyyyyyyyy
  yyyyy${c2}:mMMMMMMMMMMMMMMNho/${c1}yyyyyyyyyyy
   .yyyy${c2}:yNMMMMMMMNdyo:${c1}yyyyyyyyyyyyy.
    `yyyyyy${c2}:/++/::${c1}yyyyyyyyyyyyyyyyy`
      `yyyyyyyyyyyyyyyyyyyyyyyyyy`
        `.yyyyyyyyyyyyyyyyyyyy.`
           `.:/oosyyyysso/:.`
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

massos = AsciiArt(match=r'''"MassOS"*''', color='7', ascii=r"""
${c1} -+++/+++osyyhdmNNMMMMNdy/
 /MMMMMMMMMMMMMMMMMMMMMMMMm.
 /MMMMMMMMMMMMMMMMMMMMMMMMMm
 /MMMMMMMMMMMMMMMMMMMMMMMMMM:
 :ddddddddhddddddddhdddddddd/
 /NNNNNNNm:NNNNNNNN-NNNNNNNNo
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 :MMMMMMMN:MMMMMMMM-MMMMMMMMs
  dMMMMMMN:MMMMMMMM-MMMMMMMMs
  `yNMMMMN:MMMMMMMM-MMMMMMMMs
    `:+oss.ssssssss.ssssssss/
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

android = AsciiArt(match=r'''"Android"*''', color='2 7', ascii=r"""
${c1}         -o          o-
          +hydNNNNdyh+
        +mMMMMMMMMMMMMm+
      `dMM${c2}m:${c1}NMMMMMMN${c2}:m${c1}MMd`
      hMMMMMMMMMMMMMMMMMMh
  ..  yyyyyyyyyyyyyyyyyyyy  ..
.mMMm`MMMMMMMMMMMMMMMMMMMM`mMMm.
:MMMM-MMMMMMMMMMMMMMMMMMMM-MMMM:
:MMMM-MMMMMMMMMMMMMMMMMMMM-MMMM:
:MMMM-MMMMMMMMMMMMMMMMMMMM-MMMM:
:MMMM-MMMMMMMMMMMMMMMMMMMM-MMMM:
-MMMM-MMMMMMMMMMMMMMMMMMMM-MMMM-
 +yy+ MMMMMMMMMMMMMMMMMMMM +yy+
      mMMMMMMMMMMMMMMMMMMm
      `/++MMMMh++hMMMM++/`
          MMMMo  oMMMM
          MMMMo  oMMMM
          oNMm-  -mMNs
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

dracos = AsciiArt(match=r'''"DracOS"*''', color='1 7 3', ascii=r"""
${c1}       `-:/-
          -os:
            -os/`
              :sy+-`
               `/yyyy+.
                 `+yyyyo-
                   `/yyyys:
`:osssoooo++-        +yyyyyy/`
   ./yyyyyyo         yo`:syyyy+.
      -oyyy+         +-   :yyyyyo-
        `:sy:        `.    `/yyyyys:
           ./o/.`           .oyyso+oo:`
              :+oo+//::::///:-.`     `.`
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

pureos = AsciiArt(match=r'''"PureOS"*''', color='2 7 7', ascii=r"""
${c1}dmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmd
dNm//////////////////////////////////mNd
dNd                                  dNd
dNd                                  dNd
dNd                                  dNd
dNd                                  dNd
dNd                                  dNd
dNd                                  dNd
dNd                                  dNd
dNd                                  dNd
dNm//////////////////////////////////mNd
dmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmd
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

venom = AsciiArt(match=r'''"Venom"*''', color='8 4', ascii=r"""
${c1}
   `-`
    -yys+/-`
     `oyyyyy: /osyyyyso+:.
       /yyyyy+`+yyyyyyyyyys/.
       .-yyyyys.:+//+oyyyyyyyo.
     `oy/`oyyyyy/      ./syyyyy:
     syyys`:yyyyyo`       :yyyyy:
    /yyyyo  .syyyyy-       .yyyyy.
    yyyyy.    +yyyyy/       /yyyy/
   `yyyyy      :yyyyys`     -yyyyo
    yyyyy.      `syyyyy-    /yyyy/
    /yyyyo        /yyyyy+  .yyyyy.
     syyyys.       -yyyyys.:yyyy:
     `oyyyyyo-`     `oyyyyy:.sy:
       :syyyyyyso+/++`/yyyyyo``
         -oyyyyyyyyyyy-.syyyys.
            -/+osyyyyso.`+yyyyy/
                          .-/+syo`
                                `.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

windows_10 = AsciiArt(match=r'''*"[Windows 10]"*|*"on Windows 10"*|"Windows 8"*|         "Windows 10"* |"windows10"|"windows8"''', color='6 7', ascii=r"""
${c1}                                ..,
                    ....,,:;+ccllll
      ...,,+:;  cllllllllllllllllll
,cclllllllllll  lllllllllllllllllll
llllllllllllll  lllllllllllllllllll
llllllllllllll  lllllllllllllllllll
llllllllllllll  lllllllllllllllllll
llllllllllllll  lllllllllllllllllll
llllllllllllll  lllllllllllllllllll

llllllllllllll  lllllllllllllllllll
llllllllllllll  lllllllllllllllllll
llllllllllllll  lllllllllllllllllll
llllllllllllll  lllllllllllllllllll
llllllllllllll  lllllllllllllllllll
`'ccllllllllll  lllllllllllllllllll
       `' \*::  :ccllllllllllllllll
                       ````''*::cll
                                 ``
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

archbox = AsciiArt(match=r'''"ArchBox"*''', color='2 7 1', ascii=r"""
${c1}              ...:+oh/:::..
         ..-/oshhhhhh`   `::::-.
     .:/ohhhhhhhhhhhh`        `-::::.
 .+shhhhhhhhhhhhhhhhh`             `.::-.
 /`-:+shhhhhhhhhhhhhh`            .-/+shh
 /      .:/ohhhhhhhhh`       .:/ohhhhhhhh
 /           `-:+shhh`  ..:+shhhhhhhhhhhh
 /                 .:ohhhhhhhhhhhhhhhhhhh
 /                  `hhhhhhhhhhhhhhhhhhhh
 /                  `hhhhhhhhhhhhhhhhhhhh
 /                  `hhhhhhhhhhhhhhhhhhhh
 /                  `hhhhhhhhhhhhhhhhhhhh
 /      .+o+        `hhhhhhhhhhhhhhhhhhhh
 /     -hhhhh       `hhhhhhhhhhhhhhhhhhhh
 /     ohhhhho      `hhhhhhhhhhhhhhhhhhhh
 /:::+`hhhhoos`     `hhhhhhhhhhhhhhhhhs+`
    `--/:`   /:     `hhhhhhhhhhhho/-
             -/:.   `hhhhhhs+:-`
                ::::/ho/-`
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

puppy = AsciiArt(match=r'''"Puppy"* | "Quirky Werewolf"* | "Precise Puppy"*''', color='4 7', ascii=r"""
${c1}           `-/osyyyysosyhhhhhyys+-
  -ohmNNmh+/hMMMMMMMMNNNNd+dMMMMNM+
 yMMMMNNmmddo/NMMMNNNNNNNNNo+NNNNNy
.NNNNNNmmmddds:MMNNNNNNNNNNNh:mNNN/
-NNNdyyyhdmmmd`dNNNNNmmmmNNmdd/os/
.Nm+shddyooo+/smNNNNmmmmNh.   :mmd.
 NNNNy:`   ./hmmmmmmmNNNN:     hNMh
 NMN-    -++- +NNNNNNNNNNm+..-sMMMM-
.MMo    oNNNNo hNNNNNNNNmhdNNNMMMMM+
.MMs    /NNNN/ dNmhs+:-`  yMMMMMMMM+
 mMM+     .. `sNN+.      hMMMMhhMMM-
 +MMMmo:...:sNMMMMMms:` hMMMMm.hMMy
  yMMMMMMMMMMMNdMMMMMM::/+o+//dMMd`
   sMMMMMMMMMMN+:oyyo:sMMMNNMMMNy`
    :mMMMMMMMMMMMmddNMMMMMMMMmh/
      /dMMMMMMMMMMMMMMMMMMNdy/`
        .+hNMMMMMMMMMNmdhs/.
            .:/+ooo+/:-.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

opensuse_leap = AsciiArt(match=r'''"openSUSE Leap"* | "openSUSE_Leap"*''', color='2 7', ascii=r"""
${c2}                 `-++:`
               ./oooooo/-
            `:oooooooooooo:.
          -+oooooooooooooooo+-`
       ./oooooooooooooooooooooo/-
      :oooooooooooooooooooooooooo:
    `  `-+oooooooooooooooooooo/-   `
 `:oo/-   .:ooooooooooooooo+:`  `-+oo/.
`/oooooo:.   -/oooooooooo/.   ./oooooo/.
  `:+ooooo+-`  `:+oooo+-   `:oooooo+:`
     .:oooooo/.   .::`   -+oooooo/.
        -/oooooo:.    ./oooooo+-
          `:+ooooo+-:+oooooo:`
             ./oooooooooo/.
                -/oooo+:`
                  `:/.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

regata = AsciiArt(match=r'''"Regata"*''', color='7 1 4 5 3 2', ascii=r"""
${c1}            ddhso+++++osydd
        dho/.`hh${c2}.:/+/:.${c1}hhh`:+yd
      do-hhhhhh${c2}/sssssss+`${c1}hhhhh./yd
    h/`hhhhhhh${c2}-sssssssss:${c1}hhhhhhhh-yd
  do`hhhhhhhhh${c2}`ossssssso.${c1}hhhhhhhhhh/d
 d/hhhhhhhhhhhh${c2}`/ossso/.${c1}hhhhhhhhhhhh.h
 /hhhhhhhhhhhh${c3}`-/osyso/-`${c1}hhhhhhhhhhhh.h
shh${c4}-/ooo+-${c1}hhh${c3}:syyso+osyys/`${c1}hhh${c5}`+oo`${c1}hhh/
h${c4}`ohhhhhhho`${c3}+yyo.${c1}hhhhh${c3}.+yyo`${c5}.sssssss.${c1}h`h
s${c4}:hhhhhhhhho${c3}yys`${c1}hhhhhhh${c3}.oyy/${c5}ossssssso-${c1}hs
s${c4}.yhhhhhhhy/${c3}yys`${c1}hhhhhhh${c3}.oyy/${c5}ossssssso-${c1}hs
hh${c4}./syyys+.${c1} ${c3}+yy+.${c1}hhhhh${c3}.+yyo`${c5}.ossssso/${c1}h`h
shhh${c4}``.`${c1}hhh${c3}`/syyso++oyys/`${c1}hhh${c5}`+++-`${c1}hh:h
d/hhhhhhhhhhhh${c3}`-/osyso+-`${c1}hhhhhhhhhhhh.h
 d/hhhhhhhhhhhh${c6}`/ossso/.${c1}hhhhhhhhhhhh.h
  do`hhhhhhhhh${c6}`ossssssso.${c1}hhhhhhhhhh:h
    h/`hhhhhhh${c6}-sssssssss:${c1}hhhhhhhh-yd
      h+.hhhhhh${c6}+sssssss+${c1}hhhhhh`/yd
        dho:.hhh${c6}.:+++/.${c1}hhh`-+yd
            ddhso+++++osyhd
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

linux_mint = AsciiArt(match=r'''"Linux Mint"* | "LinuxMint"* | "mint"*''', color='2 7', ascii=r"""
${c2}             ...-:::::-...
${c2}          .-MMMMMMMMMMMMMMM-.
      .-MMMM${c1}`..-:::::::-..`${c2}MMMM-.
    .:MMMM${c1}.:MMMMMMMMMMMMMMM:.${c2}MMMM:.
   -MMM${c1}-M---MMMMMMMMMMMMMMMMMMM.${c2}MMM-
 `:MMM${c1}:MM`  :MMMM:....::-...-MMMM:${c2}MMM:`
 :MMM${c1}:MMM`  :MM:`  ``    ``  `:MMM:${c2}MMM:
.MMM${c1}.MMMM`  :MM.  -MM.  .MM-  `MMMM.${c2}MMM.
:MMM${c1}:MMMM`  :MM.  -MM-  .MM:  `MMMM-${c2}MMM:
:MMM${c1}:MMMM`  :MM.  -MM-  .MM:  `MMMM:${c2}MMM:
:MMM${c1}:MMMM`  :MM.  -MM-  .MM:  `MMMM-${c2}MMM:
.MMM${c1}.MMMM`  :MM:--:MM:--:MM:  `MMMM.${c2}MMM.
 :MMM${c1}:MMM-  `-MMMMMMMMMMMM-`  -MMM-${c2}MMM:
  :MMM${c1}:MMM:`                `:MMM:${c2}MMM:
   .MMM${c1}.MMMM:--------------:MMMM.${c2}MMM.
     '-MMMM${c1}.-MMMMMMMMMMMMMMM-.${c2}MMMM-'
       '.-MMMM${c1}``--:::::--``${c2}MMMM-.'
${c2}            '-MMMMMMMMMMMMM-'
${c2}               ``-:::::-``
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

mainsailos_small = AsciiArt(match=r'''"MainsailOS_small"*''', color='1', ascii=r"""
${c1}          -:
         +%*
       .#%%+
      -%%%: +=
     +%%#..#%%-
   .#%%+ -%%%- +=
  -%%%- +%%#..#%%+
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

garuda = AsciiArt(match=r'''"Garuda"*''', color='7 7 3 7 2 4', ascii=r"""

${c3}
                     .%;888:8898898:
                   x;XxXB%89b8:b8%b88:
                .8Xxd                8X:.
              .8Xx;                    8x:.
            .tt8x          ${c6}.d${c3}            x88;
         .@8x8;          ${c6}.db:${c3}              xx@;
       ${c4},tSXX°          .bbbbbbbbbbbbbbbbbbbB8x@;
     .SXxx            bBBBBBBBBBBBBBBBBBBBbSBX8;
   ,888S                                     pd!
  8X88/                                       q
  GBB.
   ${c5}x%88        d888@8@X@X@X88X@@XX@@X@8@X.
     dxXd    dB8b8b8B8B08bB88b998888b88x.
      dxx8o                      .@@;.
        dx88                   .t@x.
          d:SS@8ba89aa67a853Sxxad.
            .d988999889889899dd.
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

popos_small = AsciiArt(match=r'''"popos_small"* | "pop_os_small"*''', color='6 7', ascii=r"""
${c1}______
\   _ \        __
 \ \ \ \      / /
  \ \_\ \    / /
   \  ___\  /_/
    \ \    _
   __\_\__(_)_
  (___________)`
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

ubuntu_kylin = AsciiArt(match=r'''"Ubuntu Kylin"* | "Ubuntu-Kylin"*''', color='1 7 3', ascii=r"""
${c1}            .__=liiiiiii=__,
        ._=liiliii|i|i|iiilii=_.
      _=iiiii|ii|i|ii|i|inwwwzii=,
    .=liiii|ii|ii|wwww|i${c2}3QWWWW${c1}ziii=,
   =lii|i|ii|i|${c2}QQQWWWWWm]QWWQD${c1}||iiii=
  =lii|iiivw${c2}Qm${c1}>3${c2}WWWWWQWQQwwQw${c1}cii|i|ii=
 =lii|ii|n${c2}QWWWQ${c1}|)i${c2}|i${c1}%i|]${c2}TQWWWWm${c1}|ii|i|i=
.li|i|i|m${c2}WWWQV${c1}|ii${c2}wmD${c1}|iiii|${c2}TWWWWm${c1}|i|iiii,
=iii${c2}www|$WQWk${c1}|i${c2}aWWWD${c1}|i|i|ii]${c2}QQWQk${c1}|ii|i|=
iii${c2}QWWWQz$WW${c1}|i${c2}jQQWQm${c1}w|ii${c2}wW${c1}k|${c2}TTTTY${c1}i|i|iii
iiI${c2}QWQWWtyQQ${c1}|i|${c2}$WWWWWQWk${c1}||i|i|ii||i|ii|i
<|i|${c2}TTT|mQQWz${c1}|i${c2}3D${c1}]C|${c2}nD$W${c1}|ii${c2}vWWWWk${c1}||ii|i>
-|ii|i|i${c2}WWWQw${c1}|${c2}Tt${c1}|i3${c2}T${c1}|${c2}T${c1}|i|${c2}nQWQWDk${c1}|ii|ii`
 <|i|iii|${c2}VWQWWQ${c1}|i|i|||ii${c2}wmWWQWD${c1}||ii|ii+
  <|ii|i|i]${c2}$W@${c1}tv${c2}QQQWQQQWWTTHT${c1}1|iii|i|>
   <|i|ii|ii||v${c2}QWWWQWWW@vmWWWm${c1}|i|i|i>
    -<|i|ii|ii|i|${c2}TTTTTT${c1}|]${c2}QQWWWC${c1}|ii>`
      -<|i|ii|i|ii|i|i|ii3${c2}TTT${c1}t|i>`
         ~<|ii|ii|iiiii|i|||i>~
            -~~<|ii|i||i>~~`
""")
    


#!/usr/bin/env python3

"""
List distributions supported by neofetch
"""
from __future__ import annotations

import string
import textwrap
from pathlib import Path

import regex
from hypy_utils import write

from hyfetch.distros import AsciiArt

RE_SPLIT = regex.compile('EOF[ \n]*?;;')
RE_COLORS = regex.compile("""(?<=set_colors )[\"#a-zA-Z\\d ']+(?=\n)""")


def substr(s: str, start: str, end: str | None = None):
    """
    Get substring between start and end
    """
    start = s.index(start) + len(start)

    if end is None:
        return s[start:]

    return s[start:s.index(end, start)]


def parse_ascii_distros() -> list[AsciiArt]:
    """
    Parse ascii distros from neofetch script
    """
    nf = (Path(__file__).parent.parent / 'neofetch').read_text().replace('\t', ' ' * 4)

    # Get the content of "get_distro_ascii" function
    nf = nf[nf.index('get_distro_ascii() {\n'):]
    nf = nf[:nf.index('\n}\n')]

    # Remove trailing spaces
    while ' \n' in nf:
        nf = nf.replace(' \n', '\n')

    # Split by blocks
    blocks = [sub.strip() for b in regex.split('case .*? in\n', nf) for sub in RE_SPLIT.split(b)]

    # Parse blocks
    def parse_block(block: str) -> AsciiArt:
        try:
            # Get ascii art
            assert "'EOF'\n" in block
            art = substr(block, "'EOF'\n")

            # Join \
            block = block.replace('\\\n', ' ')

            # Get switch-case matching parameter
            match = block.split('\n')[0].strip()
            assert match.endswith(')')
            match = match[:-1]

            # Get colors
            color = RE_COLORS.findall(block)[0].strip("'")
            if len(color) == 0:
                raise Exception(block)

            return AsciiArt(match, color, art)

        except AssertionError:
            pass

    out = [parse_block(block) for block in blocks]
    return [v for v in out if v]


def wrap(text: str, max_len: int, leading: str):
    length = max_len - len(leading)
    lines = [line for raw in text.split('\n') for line in textwrap.wrap(raw, length) or ['']]
    return '\n'.join(leading + line if line else line for line in lines)


def generate_help(max_len: int, leading: str):
    distros = sorted(list({a.get_friendly_name() for a in parse_ascii_distros()}), key=str.casefold)

    smalls = [d.replace('_small', '') for d in distros if d.endswith('_small')]
    olds = [d.replace('_old', '') for d in distros if d.endswith('_old')]
    distros = [d for d in distros if not d.endswith('_small') and not d.endswith('_old')]

    out = f"NOTE: {', '.join(distros)} have ascii logos.\n\n"\
          f"NOTE: {', '.join(olds)} have 'old' logo variants, use {{distro}}_old to use them.\n\n" \
          f"NOTE: {', '.join(smalls)} have 'small' logo variants, use {{distro}}_small to use them."

    return wrap(out, max_len, leading)


def match_condition(match: str) -> str:
    """
    Convert simple glob match condition to python
    """
    match = [s.strip() for s in match.split("|")]
    conds = []
    for m in match:
        stripped = m.strip("*'\"").lower()
        if '*' in stripped or '"' in stripped:
            print(f"TODO: Cannot properly parse: {m}")

        # Exact matches
        if m.strip("*") == m:
            conds.append(f"name == '{stripped}'")
            continue

        # Both sides are *
        if m.startswith("*") and m.endswith("*"):
            conds.append(f"(name.startswith('{stripped}') or name.endswith('{stripped}'))")
            continue

        # Ends with *
        if m.endswith("*"):
            conds.append(f"name.startswith('{stripped}')")
            continue

        # Starts with *
        if m.startswith("*"):
            conds.append(f"name.endswith('{stripped}')")
            continue

    return ' or '.join(conds)


def export_distro(d: AsciiArt) -> str:
    """
    Export distro to a python script
    """
    # Escape variable name
    varname = d.name.lower()
    for s in string.punctuation + ' ':
        varname = varname.replace(s, '_')

    # Escape/unescape ascii
    ascii = d.ascii.replace("\\\\", "\\")
    while '"""' in ascii:
        ascii = ascii.replace('"""', '"\\""')

    script = f"""# This file is automatically generated. Please do not modify.

from . import AsciiArt

{varname} = AsciiArt(match=r'''{d.match}''', color='{d.color}', ascii=r\"""
{ascii}
\""")
    """
    write(Path(__file__).parent.parent / f'hyfetch/distros/{varname}.py', script)

    # Generate python script for identifying the distro
    return f"""
    if {match_condition(d.match)}:
        from .{varname} import {varname}
        return {varname}
    """


def export_distros():
    distros = parse_ascii_distros()
    # print('\n'.join(d.match for d in distros))
    py = """# This file is automatically generated. Please do not modify.

from __future__ import annotations

from . import AsciiArt

def detect(name: str) -> AsciiArt | None:
    if not name:
        return None
    name = name.lower()
"""
    py += '\n'.join(export_distro(d).strip('\n') for d in distros)
    write(Path(__file__).parent.parent / f'hyfetch/distros/distro_detector.py', py)


if __name__ == '__main__':
    # print(generate_help(100, ' ' * 32))
    # print(generate_help(100, '# '))
    export_distros()



# This file is automatically generated. Please do not modify.

from . import AsciiArt

hyperbola_small = AsciiArt(match=r'''"hyperbola_small"*''', color='8', ascii=r"""
${c1}    |`__.`/
    \____/
    .--.
   /    \
  /  ___ \
 / .`   `.\
/.`      `.\
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

linuxlite_small = AsciiArt(match=r'''"linuxlite_small"*''', color='3 7', ascii=r"""
${c1}   /\
  /  \
 / ${c2}/ ${c1}/
> ${c2}/ ${c1}/
\ ${c2}\ ${c1}\
 \_${c2}\${c1}_\
${c2}    \
""")
    


# This file is automatically generated. Please do not modify.

from . import AsciiArt

vzlinux = AsciiArt(match=r'''"VzLinux"*''', color='1 7 3', ascii=r"""
${c2}                 ${c1}.::::::::.${c2}
    `/////`      ${c1}:zzzzzzzz${c2}        ://///-
     VVVVVu`         ${c1}-zzz`${c2}       /VVVVV.
     `dVVVVV        ${c1}.zzz`${c2}       :VVVVV:
      `VVVVVo       ${c1}zzz${c2}        -VVVVV/
       .VVVVV\     ${c1}zzz/${c2}       .VVVVV+
        -VVVVV:   ${c1}zzzzzzzzz${c2}  .dVVVVs
         \VVVVV-  ${c1}`````````${c2}  VVVVVV
          +VVVVV.           sVVVVu`
           oVVVVd`         +VVVVd`
            VVVVVV        /VVVVV.
            `uVVVVs      -VVVVV-
             `dVVVV+    .VVVVV/
              .VVVVV\  `dVVVV+
               -VVVVV-`uVVVVo
                :VVVVVVVVVVV
                 \VVVVVVVVu
                  oVVVVVVd`
                   sVVVVV.
                    ----.
""")
    